
'********************************************************************
'*
'* File:        ViewOuAce.VBS
'* Created:     April 2000
'* Version:     1.0
'*
'* Main Function: Views an OU's Access Control Entry
'* Usage: ViewOuAce "OU=Customer1"
'*		- The root domain is automatically appended.
'*		- For a nested OU: "viewOuAce "ou=NestedOU,OU=Customer1"
'*
'* Copyright (C) 1998 Microsoft Corporation
'*
'********************************************************************
ON ERROR RESUME NEXT

'Define constants
CONST CONST_ERROR                       = 0
CONST CONST_WSCRIPT                     = 1
CONST CONST_CSCRIPT                     = 2
CONST CONST_SHOW_USAGE                  = 3
CONST CONST_PROCEED                     = 4
CONST CONST_STRING_NOT_FOUND            = -1
CONST CONST_UF_PASSWORD_CANT_CHANGE     = 64                'constants for setting user flags
CONST CONST_UF_PASSWORD_CAN_CHANGE      = 131007
CONST CONST_UF_DONT_EXPIRE_PASSWORD     = 65536
CONST CONST_UF_DO_EXPIRE_PASSWORD       = 65535

CONST SERVICES_OU			= "Services"
CONST TERMINAL_SERVERS_OU		= "Terminal Server Farm"
CONST MASTER_GROUP_ALLADMINS		= "AllAdminsGroup"
CONST MASTER_GROUP_ALLADVUSERS		= "AllAdvancedUsersGroup"
CONST MASTER_GROUP_ALLNORMAL		= "AllNormalUsersGroup"
CONST MASTER_GROUP_ALLPREMIUM		= "AllPremiumServiceGroup"
CONST MASTER_GROUP_ALLPRO		= "AllProfessionalServiceGroup"
CONST MASTER_GROUP_ALLSMALLBIZ		= "AllSmallBusinessServiceGroup"
CONST MASTER_GROUP_ALLSTANDARD		= "AllStandardServiceGroup"

' Dim Variables
Dim rootDSE
Dim AdsPath
Dim sAdServer
Dim sOuName
Dim sOuDesc
Dim sOuObj
Dim dacl
dim curServer

For i = 0 to Wscript.arguments.count - 1
    ReDim Preserve strArgumentArray(i)
    strArgumentArray(i) = Wscript.arguments.item(i)
Next

'Check whether the script is run using CScript
Select Case intChkProgram()
    Case CONST_CSCRIPT
        'Do Nothing
    Case CONST_WSCRIPT
        WScript.Echo "Please run this script using CScript." & vbCRLF & _
            "This can be achieved by" & vbCRLF & _
            "1. Using ""CScript CREATEUSERS.vbs arguments"" for Windows 95/98 or" & vbCRLF & _
            "2. Changing the default Windows Scripting Host setting to CScript" & vbCRLF & _
            "    using ""CScript //H:CScript //S"" and running the script using" & vbCRLF & _
            "    ""CREATEUSERS.vbs arguments"" for Windows NT."
        WScript.Quit
    Case Else
        WScript.Quit
End Select

' Set OU Name Variable
sOuName = strArgumentArray(0)
	If Err.Number then
		Call ShowUsage()
		wscript.Quit
	End If

Set rootDSE = GetObject("LDAP://RootDSE")
adspath = rootDSE.Get("defaultNamingContext")
rootDomain = rootDSE.Get("rootDomainNamingContext")

wscript.echo " sAdsPath: " & adspath 
wscript.echo " rootDomain: " & rootDomain


guidName = sOuName & "," & adspath

Set Ldap = GetObject("LDAP:")
wscript.Echo "guidName: " & guidName
Set obj = Ldap.GetObject("organizationalUnit", guidName)

Set SecurityDescriptor= obj.Get("ntSecurityDescriptor")

wScript.Echo "Owner: " & SecurityDescriptor.Owner
wScript.Echo "Group: " & SecurityDescriptor.Group

Set Dacl = SecurityDescriptor.DiscretionaryACL
wScript.Echo Dacl.AceCount

For Each x in Dacl
	wScript.Echo "Trustee: " & x.Trustee
	wScript.Echo "AccessMask: " & x.AccessMask
	wScript.Echo "AceFlags: " & x.AceFlags
	wScript.Echo "AceType: " & x.AceType
	wScript.Echo "Flags: " & x.Flags
	wScript.Echo "ObjectType: " & x.ObjectType
Next

'********************************************************************
'*
'* Sub ShowUsage()
'* Purpose: Shows the correct usage to the user.
'* Input:   None
'* Output:  Help messages are displayed on screen.
'*
'********************************************************************

Private Sub ShowUsage()

    Wscript.echo " "
    Wscript.echo "Views an OU's Access Control Entry" & vbCRLF
    Wscript.echo " "
    Wscript.echo "ViewOuAce ""OU=Customer1"""
    Wscript.echo "   - The root domain is automatically appended."
    Wscript.echo "   - For a nested OU: viewOuAce ""ou=NestedOU,OU=Customer1"""

End Sub

'********************************************************************
'*
'* Function intChkProgram()
'* Purpose: Determines which program is used to run this script.
'* Input:   None
'* Output:  intChkProgram is set to one of CONST_ERROR, CONST_WSCRIPT,
'*          and CONST_CSCRIPT.
'*
'********************************************************************

Private Function intChkProgram()

    ON ERROR RESUME NEXT

    Dim strFullName, strCommand, i, j

    'strFullName should be something like C:\WINDOWS\COMMAND\CSCRIPT.EXE
    strFullName = WScript.FullName
    If Err.Number then
        Print "Error 0x" & CStr(Hex(Err.Number)) & " occurred."
        If Err.Description <> "" Then
            Print "Error description: " & Err.Description & "."
        End If
        intChkProgram =  CONST_ERROR
        Exit Function
    End If

    i = InStr(1, strFullName, ".exe", 1)
    If i = 0 Then
        intChkProgram =  CONST_ERROR
        Exit Function
    Else
        j = InStrRev(strFullName, "\", i, 1)
        If j = 0 Then
            intChkProgram =  CONST_ERROR
            Exit Function
        Else
            strCommand = Mid(strFullName, j+1, i-j-1)
            Select Case LCase(strCommand)
                Case "cscript"
                    intChkProgram = CONST_CSCRIPT
                Case "wscript"
                    intChkProgram = CONST_WSCRIPT
                Case Else       'should never happen
                    Print "An unexpected program is used to run this script."
                    Print "Only CScript.Exe or WScript.Exe can be used to run this script."
                    intChkProgram = CONST_ERROR
            End Select
        End If
    End If

End Function