<%
'********************************************************************
'*				---   Web Admin   ---
'*
'* Created By: Conrad Agramont & Ed Tremblay
'*
'* DnsLib.asp
'* 
'* Notes:   	
'*			- Any Items marked optional with [braces] need to have a 
'*				blank string passed into the function.
'*
'*			- More Information:  http://www.microsoft.com/ISN
'*
'* Copyright (C) 1999 Microsoft Corporation
'*
'********************************************************************


'********************************************************************
'*                                                                  *
'*                           Start of Server                        *
'*                                                                  *
'********************************************************************
    'Define constants
    CONST CONST_ERROR                   = 0
    CONST CONST_WSCRIPT                 = 1
    CONST CONST_CSCRIPT                 = 2
    CONST CONST_SHOW_USAGE              = 3
    CONST CONST_DISPLAY                 = 4
    CONST CONST_LIST                    = 5
    CONST CONST_SERVICE                 = 6
    CONST CONST_START                   = 7
    CONST CONST_STOP                    = 8
    CONST CONST_RESTART                 = 9
    CONST CONST_MODIFY                  = 10
    CONST CONST_ZONE                    = 11
    CONST CONST_ADD                     = 12
    CONST CONST_DELETE                  = 13
    
    ' Declare Public Variables
    Dim cResource
    
    Public strContainerName
    Public strDnsServerName
    Public strDomainName
    Public strOwnerName
    Public strTTL
    Public strRecordData
    Public strText
    Public strRelPath
    Public strClassType
    Public strClass
    Public intParseArguments
    Public strModifyPropertyArray()

'********************************************************************
'*
'* Function DnsServerList()
'*
'* Purpose: Lists the Value of all server properties.
'*
'* Input:   strServer           a machine name
'*          strUserName         the current user's name
'*          strPassword         the current user's password
'*
'* Output:  Results are either printed on screen or saved in strOutputFile.
'*
'********************************************************************

Function DnsServerList(strServer     , _
                  strUserName   , _
                  strPassword )


    'ON ERROR RESUME NEXT

    Dim objFileSystem, objService, objDnsSet, objDNS
    Dim strWBEMClass

    'Establish a connection with the server.
    If blnConnect("root\microsoftdns" , _
                   strUserName , _
                   strPassword , _
                   strServer   , _
                   objService  ) Then
        Response.Write("")
        Response.Write("Please check the server name, " _
                        & "credentials and WBEM Core.")
        Exit Function
    End If

    strWBEMClass = "MicrosoftDNS_Server"

    Set objDNS = objService.Get("MicrosoftDNS_Server.Name="".""")
    
    Set DnsServerList = objDNS
    
End Function           

'********************************************************************
'*
'* Sub DnsService()
'*
'* Purpose: Stops, starts, or restarts the DNS Server.
'*
'* Input:   strServer           a machine name
'*          strUserName         the current user's name
'*          strPassword         the current user's password
'*          intServiceTask      The job to perform
'*
'* Output:  Results are either printed on screen or saved in strOutputFile.
'*
'********************************************************************

Private Sub DnsService(strServer     , _
                       strUserName   , _
                       strPassword   , _
                       intServiceTask )

    ON ERROR RESUME NEXT

    Dim objFileSystem, objService, objDnsSet, objDNS
    Dim intStatus
    Dim strWBEMClass


    'Establish a connection with the server.
    If blnConnect("root\microsoftdns" , _
                   strUserName , _
                   strPassword , _
                   strServer   , _
                   objService  ) Then
        Response.Write("")
        Response.Write("Please check the server name, " _
                        & "credentials and WBEM Core.")
        Exit Sub
    End If
    strWBEMClass = "MicrosoftDNS_Server"

    Set objDNSSet = objService.Get("MicrosoftDNS_Server.name="".""")
    If blnErrorOccurred(" DNS Server not available.") then Exit Sub
    Select Case intServiceTask
        Case CONST_START
            intStatus = objDnsSet.StartService
        Case CONST_STOP
            intStatus = objDNSSet.StopService
        Case CONST_RESTART
            intStatus = objDNSSet.RestartDNSServer
    End Select

    If blnErrorOccurred(" DNS Service was not changed.") then
        Exit Sub
    Else
        Call WriteLine("Operation successful.")
    End If
    
End Sub

'********************************************************************
'*
'* Sub DnsModify()
'*
'* Purpose: Stops, starts, or restarts the DNS Server.
'*
'* Input:   strServer           a machine name
'*          strUserName         the current user's name
'*          strPassword         the current user's password
'*          strPropertyArray    The properties to change
'*          strValueArray       The New Values
'*
'* Output:  Results are either printed on screen or saved in strOutputFile.
'*
'********************************************************************

Private Sub DnsModify(strServer        , _
                      strUserName      , _
                      strPassword      , _
                      strPropertyArray , _
                      strValueArray    )
                      
    ON ERROR RESUME NEXT

    Dim objFileSystem, objService, objDnsSet, objDNS
    Dim intStatus
    Dim strWBEMClass
    
    'Establish a connection with the server.
    If blnConnect("root\microsoftdns" , _
                   strUserName , _
                   strPassword , _
                   strServer   , _
                   objService  ) Then
        Response.Write("")
        Response.Write("Please check the server name, " _
                        & "credentials and WBEM Core.")
        Exit Sub
    End If
    strWBEMClass = "MicrosoftDNS_Server"

    Set objDNSSet = objService.Get("MicrosoftDNS_Server.Name="".""")
    If blnErrorOccurred(" DNS Server not available.") then Exit Sub


    For I = LBound(strPropertyArray) to UBound(strPropertyArray)
        If Not IsEmpty(strPropertyArray(I)) then
            Select Case lcase(strPropertyArray(I))
                Case "slave"
                    objDNSSet.Slave = strValueArray(I)
                Case "autocacheupdate"
                    objDNSSet.AutoCacheUpdate = strValueArray(I)
                Case "maxCachettl"
                    objDNSSet.MaxCacheTTL = strValueArray(I)
                Case "addressanswerlimit"
                    objDNSSet.AddressAnswerLimit = strValueArray(I)
                Case "allowupdate"
                    objDNSSet.AllowUpdate = strValueArray(I)
                Case "slowzonetransfer"
                    objDNSSet.SlowZoneTransfer = strValueArray(I)
                Case "disjointnets"
                    objDNSSet.DisjointNets = strValueArray(I)
                Case "forwarddelegation"
                    objDNSSet.ForwardDelegation = strValueArray(I)
                Case "localnetpriority"
                    objDNSSet.LocalNetPriority = strValueArray(I)
                Case "rpcprotocol"
                    objDNSSet.RpcProtocol = strValueArray(I)
                Case "sendonnondnsport"
                    objDNSSet.SendOnNonDnsPort = strValueArray(I)
                Case "dspollinginterval"
                    objDNSSet.DsPollingInterval = strValueArray(I)
                Case "forwardtimeout"
                    objDNSSet.ForwardTimeout = strValueArray(I)
                Case "eventloglevel"
                    objDNSSet.EventLogLevel = strValueArray(I)
                Case "loglevel"
                    objDNSSet.LogLevel = strValueArray(I)
                Case "autoreversezones"
                    objDNSSet.AutoReverseZones = strValueArray(I)
                Case "bootmethod"
                    objDNSSet.BootMethod = strValueArray(I)
                Case "loosewildcarding"
                    objDNSSet.LooseWildcarding = strValueArray(I)
                Case "namecheckflag"
                    objDNSSet.NameCheckFlag = strValueArray(I)
                Case "roundrobin"
                    objDNSSet.RoundRobin = strValueArray(I)
                Case "secureresponses"
                    objDNSSet.SecureResponses = strValueArray(I)
                Case "strictfileparsing"
                    objDNSSet.StrictFileParsing = strValueArray(I)
                Case "norecursion"
                    objDNSSet.NoRecursion = strValueArray(I)
                Case "recursionretry"
                    objDNSSet.RecursionRetry = strValueArray(I)
                Case "recursiontimeout"
                    objDNSSet.RecursionTimeout = strValueArray(I)
                Case "writeauthorityns"
                    objDNSSet.WriteAuthorityNS = strValueArray(I)
                Case "writeauthoritysoa"
                    objDNSSet.WriteAuthoritySOA = strValueArray(I)
                Case Else
                    Call WriteLine(strPropertyArray(I) & " is not valid.")
                    Exit Sub
            End Select
        End If
    Next
    objDNSSet.Put_
    If blnErrorOccurred("Server properties not updated.") then
        Exit Sub
    Else
        Call WriteLine("Server properties are now updated.")
    End If 

End Sub

'********************************************************************
'*
'* Sub DnsADDIP()
'*
'* Purpose: Adds an IP Addresses to an Array.
'*
'* Input:   strServer           a machine name
'*          strUserName         the current user's name
'*          strPassword         the current user's password
'*          strPropertyArray    The properties to change
'*          strValueArray       The New Values
'*
'* Output:  Results are either printed on screen or saved in strOutputFile.
'*
'********************************************************************

Private Sub DnsADDIP(strServer        , _
                     strUserName      , _
                     strPassword      , _
                     strPropertyArray , _
                     strValueArray    )

    ON ERROR RESUME NEXT
    Dim objFileSystem, objService, objDnsSet, objDNS
    Dim strTempArray()
    Dim intStatus, J, H
    Dim strWBEMClass
    Redim strTempArray(20)

    'Establish a connection with the server.
    If blnConnect("root\microsoftdns" , _
                   strUserName , _
                   strPassword , _
                   strServer   , _
                   objService  ) Then
        Response.Write("")
        Response.Write("Please check the server name, " _
                        & "credentials and WBEM Core.")
        Exit Sub
    End If

    strWBEMClass = "MicrosoftDNS_Server"
    Set objDNSSet = objService.Get("MicrosoftDNS_Server.Name="".""")
    If blnErrorOccurred(" DNS Server not available.") then Exit Sub
    
    For I = 0 to ubound(strPropertyArray)
        If Not IsEmpty(strPropertyArray(I)) then
            Select Case lcase(strPropertyArray(I))
                Case "forwardersipaddressesarray"
                    Redim strTempArray(20)
                    If IsNull(objDNSSet.forwardersipaddressesarray) then
                        strTempArray(0) = strValueArray(I)
                        Redim Preserve strTempArray(0)
                        objDNSSet.forwardersipaddressesarray = strTempArray
                    Else
                        J = 0
                        For H = lbound(objDNSSet.forwardersipaddressesarray) to ubound(objDNSSet.forwardersipaddressesarray)
                            strTempArray(H) = objDNSSet.forwardersipaddressesarray(H)
                            J = J + 1
                        Next
                        strTempArray(J) = strValueArray(I)
                        ReDim Preserve strTempArray(J)
                        objDNSSet.forwardersipaddressesarray = strTempArray
                    End If
                    objDNSSet.Put_
                    If err.Number <> 0 then
                        Call WriteLine("Error adding IP address.")
                        Exit Sub                        
                    Else
                        Call WriteLine("IP address successfully added.")
                    End If

                Case "listenipaddressesarray"
                    Redim strTempArray(20)
                    If IsNull(objDNSSet.ListenIPAddressesArray) then
                        strTempArray(0) = strValueArray(I)
                        Redim Preserve strTempArray(0)
                        objDNSSet.ListenIPAddressesArray = strTempArray
                    Else
                        J = 0
                        For H = lbound(objDNSSet.ListenIPAddressesArray) to ubound(objDNSSet.ListenIPAddressesArray)
                            strTempArray(H) = objDNSSet.ListenIPAddressesArray(H)
                            J = J + 1
                        Next
                        strTempArray(J) = strValueArray(I)
                        ReDim  Preserve strTempArray(J)
                        objDNSSet.ListenIPAddressesArray = strTempArray
                    End If
                    objDNSSet.Put_
                    If err.Number <> 0 then
                        Call WriteLine("Error adding IP address.")
                        Exit Sub                        
                    Else
                        Call WriteLine("IP address successfully added.")
                    End If
                
                Case Else
                    Call WriteLine("Cannot add an IP address to " & strPropertyArray(I))

            End Select
        End If    
    
    Next
    
End Sub

'********************************************************************
'*
'* Sub DnsDELETEIP()
'*
'* Purpose: Removes IP addresses from arrays.
'*
'* Input:   strServer           a machine name
'*          strUserName         the current user's name
'*          strPassword         the current user's password
'*          strPropertyArray    The properties to change
'*          strValueArray       The New Values
'*
'* Output:  Results are either printed on screen or saved in strOutputFile.
'*
'********************************************************************

Private Sub DnsDELETEIP(strServer        , _
                        strUserName      , _
                        strPassword      , _
                        strPropertyArray , _
                        strValueArray    )

    ON ERROR RESUME NEXT
    Dim objFileSystem, objService, objDnsSet, objDNS
    Dim strTempArray()
    Dim intStatus, J, H
    Dim strWBEMClass
    Redim strTempArray(20)

    'Establish a connection with the server.
    If blnConnect("root\microsoftdns" , _
                   strUserName , _
                   strPassword , _
                   strServer   , _
                   objService  ) Then
        Response.Write("")
        Response.Write("Please check the server name, " _
                        & "credentials and WBEM Core.")
        Exit Sub
    End If

    strWBEMClass = "MicrosoftDNS_Server"
    Set objDNSSet = objService.Get("MicrosoftDNS_Server.Name="".""")
    If blnErrorOccurred(" DNS Server not available.") then Exit Sub
    
    For I = 0 to ubound(strPropertyArray)
        If Not IsEmpty(strPropertyArray(I)) then
            Select Case lcase(strPropertyArray(I))
                Case "forwardersipaddressesarray"
                    Redim strTempArray(20)
                    If IsNull(objDNSSet.forwardersipaddressesarray) then
                        Call WriteLine("There is no IP addresses to delete.")
                    Else
                        J = 0
                        For H = lbound(objDNSSet.forwardersipaddressesarray) to ubound(objDNSSet.forwardersipaddressesarray)
                            If strValueArray(I) <> objDNSSet.forwardersipaddressesarray(H) then
                                strTempArray(J) = objDNSSet.forwardersipaddressesarray(H)
                                J = J + 1
                            End If
                        Next
                        If J <> 0 then
                            ReDim Preserve strTempArray(J - 1)
                            objDNSSet.forwardersipaddressesarray = strTempArray
                        Else
                            objDnsSet.ForwardersIpAddressesArray = Null
                        End If
                    End If
                    objDNSSet.Put_
                    If err.Number <> 0 then
                        Call WriteLine("Error deleting IP address.")
                        Exit Sub                        
                    Else
                        Call WriteLine("IP address successfully deleted.")
                    End If

                Case "listenipaddressesarray"
                    Redim strTempArray(20)
                    If IsNull(objDNSSet.listenipaddressesarray) then
                        Call WriteLine("There is no IP addresses to delete.")
                    Else
                        J = 0
                        For H = lbound(objDNSSet.listenipaddressesarray) to ubound(objDNSSet.listenipaddressesarray)
                            If strValueArray(I) <> objDNSSet.listenipaddressesarray(H) then
                                strTempArray(J) = objDNSSet.listenipaddressesarray(H)
                                J = J + 1
                            End If
                        Next
                        If J <> 0 then
                            ReDim Preserve strTempArray(J - 1)
                            objDNSSet.listenipaddressesarray = strTempArray
                        Else
                            objDnsSet.ForwardersIpAddressesArray = Null
                        End If
                    End If
                    objDNSSet.Put_
                    If err.Number <> 0 then
                        Call WriteLine("Error deleting IP address.")
                        Exit Sub                        
                    Else
                        Call WriteLine("IP address successfully deleted.")
                    End If

                
                Case Else
                    Call WriteLine("Cannot add an IP address to " & strPropertyArray(I))

            End Select
        End If    
    
    Next

End Sub

'********************************************************************
'*
'* Sub DnsZone()
'*
'* Purpose: Lists instances of MicrosoftDNS_ServerDomainContainment.
'*
'* Input:   strServer           a machine name
'*          strUserName         the current user's name
'*          strPassword         the current user's password
'*
'* Output:  Results are either printed on screen or saved in strOutputFile.
'*
'********************************************************************

Private Sub DnsZone(strServer        , _
                    strUserName      , _
                    strPassword      )


    ON ERROR RESUME NEXT
    Dim objFileSystem, objService, objDnsSet, objDNS
    Dim strTempArray()
    Dim intStatus, J, H
    Dim strWBEMClass
    Redim strTempArray(20)
    
    If blnContextHelp then
        Wscript.Echo ""
        Wscript.Echo "Enumerates Domains associated with the Dns Server."
        Wscript.Echo ""
        Wscript.Echo "SYNTAX:"
        Wscript.Echo "  DnsServer Zone"
        Wscript.Echo "    [/S <server>] [/U <username>] [/W <password>]"
        Wscript.Echo "    [/O <outputfile>]"
        Wscript.Echo ""
        Wscript.Echo "PARAMETER SPECIFIERS:"
        Wscript.Echo "   server        A machine name."
        Wscript.Echo "   username      The current user's name."
        Wscript.Echo "   password      Password of the current user."
        Wscript.Echo "   outputfile    The output file name."
        Wscript.Echo ""
        Wscript.Echo "EXAMPLE"
        Wscript.Echo ""
        Wscript.Echo "  DnsServer.vbs Zone"
        Wscript.Echo ""
        Exit Sub
    End If

    
    'Open a text file for output if the file is requested
    If Not IsEmpty(strOutputFile) Then
        If (NOT blnOpenFile(strOutputFile)) Then
            Response.Write ("Could not open an output file.")
            Exit Sub
        End If
    End If

    'Establish a connection with the server.
    If blnConnect("root\microsoftdns" , _
                   strUserName , _
                   strPassword , _
                   strServer   , _
                   objService  ) Then
        Response.Write("")
        Response.Write("Please check the server name, " _
                        & "credentials and WBEM Core.")
        Exit Sub
    End If
    dim Inst
    'Set objDNSSet = objService.AssociatorsOf("MicrosoftDNS_Server")
    Set objDNSSet = objService.InstancesOf("MicrosoftDNS_ServerDomainContainment")
    If blnErrorOccurred(" DNS Server not available.") then Exit Sub
    Dim strTemp
    Stop
    For Each inst in objDnsSet
        strTemp = Inst.PartComponent & " "
        Do Until Len(strTemp) = 0
            I = 1
            Do Until Mid(strTemp,I,1) = ","
                If I = Len(strTemp) then Exit Do
                I = I + 1
            Loop
            Call WriteLine(Left(strTemp,I - 1))
            strTemp = Right(strTemp,Len(StrTemp) - I)
        Loop
        Call WriteLine("")
    Next
        
    If IsObject(objOutputFile) Then
        objOutputFile.Close
        Response.Write ("Results are saved in file " & strOutputFile & ".")
    End If


End Sub


'********************************************************************
'* General Routines
'********************************************************************

'********************************************************************
'*
'* Function strDisplayNull()
'*
'* Purpose: Returns the input or a "<NULL>" string.
'*
'* Input:   strProperty     the property to be evaualted
'*
'* Output:  The input or a "<NULL"> string.
'*
'********************************************************************

Function strDisplayNull(strProperty)

    If IsNull(strProperty) then
        strDisplayNull = "<NULL>"
    Else
        strDisplayNull = strProperty
    End If

End Function

'********************************************************************
'*
'* Function strPackString()
'*
'* Purpose: Attaches spaces to a string to increase the length to intWidth.
'*
'* Input:   strString   a string
'*          intWidth    the intended length of the string
'*          blnAfter    Should spaces be added after the string?
'*          blnTruncate specifies whether to truncate the string or not if
'*                      the string length is longer than intWidth
'*
'* Output:  strPackString is returned as the packed string.
'*
'********************************************************************
Private Function strPackString( ByVal strString, _
                                ByVal intWidth,  _
                                ByVal blnAfter,  _
                                ByVal blnTruncate)

    ON ERROR RESUME NEXT

    intWidth      = CInt(intWidth)
    blnAfter      = CBool(blnAfter)
    blnTruncate   = CBool(blnTruncate)

    If Err.Number Then
        Response.Write ("Argument type is incorrect!")
        Err.Clear
        Wscript.Quit
    End If

    If IsNull(strString) Then
        strPackString = "null" & Space(intWidth-4)
        Exit Function
    End If

    strString = CStr(strString)
    If Err.Number Then
        Response.Write ("Argument type is incorrect!")
        Err.Clear
        Wscript.Quit
    End If

    If intWidth > Len(strString) Then
        If blnAfter Then
            strPackString = strString & Space(intWidth-Len(strString))
        Else
            strPackString = Space(intWidth-Len(strString)) & strString & " "
        End If
    Else
        If blnTruncate Then
            strPackString = Left(strString, intWidth-1) & " "
        Else
            strPackString = strString & " "
        End If
    End If

End Function

'********************************************************************
'*
'* Function blnConnect()
'*
'* Purpose: Connects to machine strServer.
'*
'* Input:   strServer       a machine name
'*          strNameSpace    a namespace
'*          strUserName     name of the current user
'*          strPassword     password of the current user
'*
'* Output:  objService is returned  as a service object.
'*          strServer is set to local host if left unspecified
'*
'********************************************************************
Private Function blnConnect(ByVal strNameSpace, _
                            ByVal strUserName,  _
                            ByVal strPassword,  _
                            ByRef strServer,    _
                            ByRef objService)

    ON ERROR RESUME NEXT

    Dim objLocator, objWshNet

    blnConnect = False     'There is no error.

    'Create Locator object to connect to remote CIM object manager
    Set objLocator = CreateObject("WbemScripting.SWbemLocator")
    'If Err.Number then
    '    Response.Write( "Error 0x" & CStr(Hex(Err.Number)) & _
    '                       " occurred in creating a locator object." )
    '   If Err.Description <> "" Then
    '        Response.Write( "Error description: " & Err.Description & "." )
    '    End If
    '    Err.Clear
    '    blnConnect = True     'An error occurred
    '    Exit Function
    'End If
	
    'Get the current server's name if left unspecified
    If IsEmpty(strServer) Then
        Set objWshNet = CreateObject("Wscript.Network")
		strServer     = objWshNet.ComputerName
    End If
	
    'Connect to the namespace which is either local or remote
    Set objService = objLocator.ConnectServer (strServer, strNameSpace, strUserName, strPassword)
    ObjService.Security_.impersonationlevel = 3
    If Err.Number then
        Response.Write "Error 0x" & CStr(Hex(Err.Number)) & " occurred in connecting to server " _
           & strServer & "."
        If Err.Description <> "" Then
			Response.Write "<BR>"
            Response.Write "Error description: " & Err.Description & "." 
        End If
        Err.Clear
        blnConnect = True     'An error occurred
    End If


End Function

'********************************************************************
'* 
'* Function blnErrorOccurred()
'*
'* Purpose: Reports error with a string saying what the error occurred in.
'*
'* Input:   strIn		string saying what the error occurred in.
'*
'* Output:  displayed on screen 
'* 
'********************************************************************
Private Function blnErrorOccurred (ByVal strIn)

    If Err.Number Then
        Response.Write   "Error 0x" & CStr(Hex(Err.Number)) & ": " & strIn
        If Err.Description <> "" Then
            Response.Write  "Error description: " & Err.Description
        End If
        Err.Clear
        blnErrorOccurred = True
    Else
        blnErrorOccurred = False
    End If

End Function

Sub WriteLine(strResponseInfo)
	Response.Write strResponseInfo
	Response.Write "<BR>" & Chr(10)
end Sub

'********************************************************************
'*                                                                  *
'*                           End of Server                          *
'*                                                                  *
'********************************************************************

'********************************************************************
'*                                                                  *
'*                           Start of Zones                         *
'*                                                                  *
'********************************************************************

    'Define constants
    'CONST CONST_ERROR                   = 0
    'CONST CONST_WSCRIPT                 = 1
    'CONST CONST_CSCRIPT                 = 2
    'CONST CONST_SHOW_USAGE              = 3
    'CONST CONST_DISPLAY                 = 4
    'CONST CONST_LIST                    = 5
    CONST CONST_CREATE                  = 6
    'CONST CONST_MODIFY                  = 7
    'CONST CONST_DELETE                  = 8
    CONST CONST_ADDIP                   = 9
    CONST CONST_DELETEIP                = 10
    CONST CONST_PAUSE                   = 11
    CONST CONST_RESUME                  = 12
    CONST CONST_WRITE                   = 13
    CONST CONST_UPDATE                  = 14
    CONST CONST_RELOAD                  = 15
    CONST CONST_REFRESH                 = 16
    
    'Declare variables
    Dim intOpMode, i
    Dim strServer, strUserName, strPassword, strOutputFile
    Dim strPropertyArray(), strValueArray(), strZoneArray()
    Dim blnContextHelp
 '********************************************************************
'*
'* Function GetDNSZoneInfo
'*
'* Purpose: Lists the Value of all server properties.
'*
'* Input:   strServer           a machine name
'*          strUserName         the current user's name
'*          strPassword         the current user's password
'*          strProperty			a array of zone name
'*
'* Output:  Results are either printed on screen or saved in strOutputFile.
'*
'********************************************************************

Function GetDNSZoneInfo(strServer        , _
						strUserName      , _
						strPassword      , _
						strProperty  )


    ON ERROR RESUME NEXT

    Dim objFileSystem, objService, objDNS, objInst, objServer
    Dim strMessage
    
    'Establish a connection with the server.
    If blnConnect("root\microsoftdns" , _
                   strUserName , _
                   strPassword , _
                   strServer   , _
                   objService  ) Then
       Response.Write "<BR>"
       Response.Write "Please check the server name, " _
                        & "credentials and WBEM Core."
        Exit Function
    End If

        set objServer = objService.Get("MicrosoftDNS_Server.name="".""")
        Set objDNS = objService.Get("MicrosoftDNS_Zone.ContainerName=""" & strProperty & """,DnsServerName=""" & objServer.Name & """,Name=""" & strProperty & """")
        If blnErrorOccurred("Zone not available.") then Exit Function
        
        ' Return the Zone Object
        Set GetDNSZoneInfo = objDNS

End Function      
 
'********************************************************************
'*
'* Function DnsZoneList()
'*
'* Purpose: Lists the Value of all server properties.
'*
'* Input:   strServer           a machine name
'*          strUserName         the current user's name
'*          strPassword         the current user's password
'*          blnContextHelp      show context sensitve help
'*
'* Output:  Results are either printed on screen or saved in strOutputFile.
'*
'********************************************************************

Function DnsZoneList(strServer        , _
                strUserName      , _
                strPassword      )


    ON ERROR RESUME NEXT

    Dim objFileSystem, objService, objDNS, objInst, objServer
    Dim strMessage
    
    'Establish a connection with the server.
    If blnConnect("root\microsoftdns" , _
                   strUserName , _
                   strPassword , _
                   strServer   , _
                   objService  ) Then
        Call Wscript.Echo("")
        Call Wscript.Echo("Please check the server name, " _
                        & "credentials and WBEM Core.")
        Exit Function
    End If

        Set objDNS = objService.InstancesOf("MicrosoftDNS_Zone")
        If blnErrorOccurred(" DNS Server not available.") then Exit Function

    Set DnsZoneList = objDNS

End Function           

'********************************************************************
'*
'* Sub DnsCreate()
'*
'* Purpose: Creates a Zone.
'*
'* Input:   strServer           a machine name
'*          strUserName         the current user's name
'*          strPassword         the current user's password
'*          intServiceTask      The job to perform
'*
'* Output:  Results are either printed on screen or saved in strOutputFile.
'*
'********************************************************************

Private Sub DnsCreate(strServer        , _
                      strUserName      , _
                      strPassword      , _
                      strOutputFile    , _
                      strPropertyArray )
    ON ERROR RESUME NEXT

    Dim objFileSystem, objService, objDnsSet, objServer, objInst
    Dim strTempArray(0)

    'Establish a connection with the server.
    If blnConnect("root\microsoftdns" , _
                   strUserName , _
                   strPassword , _
                   strServer   , _
                   objService  ) Then
        Call Wscript.Echo("")
        Call Wscript.Echo("Please check the server name, " _
                        & "credentials and WBEM Core.")
        Exit Sub
    End If

    set objServer = objService.Get("MicrosoftDNS_Server.name="".""")
    Set objDNSSet = objService.Get("MicrosoftDNS_ZONE")
    If blnErrorOccurred(" DNS Server not available.") then Exit Sub

    Select Case strPropertyArray(0)
        Case 2
            strTempArray(0) = strPropertyArray(4)
            If IsEmpty(strPropertyArray(3)) Then
                ObjInst = objDNSSet.CreateZone(strPropertyArray(2), strPropertyArray(0),,strTempArray)
            Else
                ObjInst = objDNSSet.CreateZone(strPropertyArray(2), strPropertyArray(0), strPropertyArray(3),strTempArray)
            End If
        
        Case Else
            If IsEmpty(strPropertyArray(3)) Then
                ObjInst = objDNSSet.CreateZone(strPropertyArray(2), strPropertyArray(0))
            Else
                ObjInst = objDNSSet.CreateZone(strPropertyArray(2), strPropertyArray(0), strPropertyArray(3))
            End If

    
    End Select

    If blnErrorOccurred(" DNS Zone not created.") then
        Exit Sub
    Else
        Call WriteLine("Operation successful.")
    End If
    
End Sub

'********************************************************************
'*
'* Sub DnsModify()
'*
'* Purpose: Stops, starts, or restarts the DNS Server.
'*
'* Input:   strServer           a machine name
'*          strUserName         the current user's name
'*          strPassword         the current user's password
'*          strPropertyArray    The properties to change
'*          strValueArray       The New Values
'*
'* Output:  Results are either printed on screen or saved in strOutputFile.
'*
'********************************************************************

Private Sub DnsModify(strServer        , _
                      strUserName      , _
                      strPassword      , _
                      strPropertyArray , _
                      strValueArray    , _
                      strZoneArray      )
                      
'    ON ERROR RESUME NEXT
    Dim objFileSystem, objService, objDnsSet, objServer, objInst
    Dim strTempArray(0), strZoneFile, strMastersIP(0), G
    Dim blnError, blnContinue

    'Establish a connection with the server.
    If blnConnect("root\microsoftdns" , _
                   strUserName , _
                   strPassword , _
                   strServer   , _
                   objService  ) Then
        Call Wscript.Echo("")
        Call Wscript.Echo("Please check the server name, " _
                        & "credentials and WBEM Core.")
        Exit Sub
    End If

    set objServer = objService.Get("MicrosoftDNS_Server.name="".""")
    'Find ZoneType Changes
    For I = LBound(strZoneArray) to UBound(strZoneArray)
        If lcase(strPropertyArray(I)) = "zonetype" then
            Select Case strValueArray(I)
                Case 0
                    Set objDNSSet = objService.Get("MicrosoftDNS_Zone.ContainerName=""" & strZoneArray(i) & """,DnsServerName=""" & objServer.Name & """,Name=""" & strZoneArray(i) & """")
                    objInst = objDNSSet.ChangeZoneType(0)
                    strPropertyArray(I) = "skip"
                    Call WriteLine ("Zone type has been changed to DS Intergrated.")
                Case 1
                    For G = LBound(strZoneArray) to UBound(strZoneArray)
                        If lcase(strPropertyArray(G)) = "zonefile" then
                            blnContinue = True
                            strZoneFile = strValueArray(G)
                            strPropertyArray(G) = "skip"
                        End If
                    Next
                    If blnContinue = False then
                        Call WriteLine("In order to change the Zone Type to Primary you must specify a zonefile.")
                        Exit Sub
                    End If
                    Set objDNSSet = objService.Get("MicrosoftDNS_Zone.ContainerName=""" & strZoneArray(i) & """,DnsServerName=""" & objServer.Name & """,Name=""" & strZoneArray(i) & """")
                    objInst = objDNSSet.ChangeZoneType(1,strZoneFile)
                    strPropertyArray(I) = "skip"
                    Call WriteLine ("Zone type has been changed to Primary.")
                Case 2
                    For G = Lbound(strZoneArray) to UBound(strZoneArray)
                        If lcase(strPropertyArray(G)) = "mastersip" then
                            blnContinue = True
                            strMastersIP(0) = strValueArray(G)
                            strPropertyArray(G) = "skip"
                        End If
                    Next
                    If blnContinue = False then
                        Call WriteLine("In order to change the Zone Type to Secondary you must specify a Masters IP Address.")
                        Exit Sub
                    End If
                    Set objDNSSet = objService.Get("MicrosoftDNS_Zone.ContainerName=""" & strZoneArray(i) & """,DnsServerName=""" & objServer.Name & """,Name=""" & strZoneArray(i) & """")
                    objInst = objDNSSet.ChangeZoneType(2,,strMastersIP)
                    strPropertyArray(I) = "skip"
                    Call WriteLine ("Zone type has been changed to secondary.")
            End Select
        End If
    Next
    For I = LBound(strZoneArray) to UBound(strZoneArray)
        If Not IsEmpty(strZoneArray(i)) then
            Set objDNSSet = objService.Get("MicrosoftDNS_Zone.ContainerName=""" & strZoneArray(i) & """,DnsServerName=""" & objServer.Name & """,Name=""" & strZoneArray(i) & """")
            If blnErrorOccurred(" DNS Server not available.") then Exit Sub

            If Not IsEmpty(strPropertyArray(I)) then
                blnError = False
                Select Case lcase(strPropertyArray(I))
                    Case "allowupdate"
                        objDNSSet.AllowUpdate = strValueArray(I)
                        objDNSSet.Put_
                    Case "disablewins"
                        objDNSSet.DisableWins = strValueArray(I)
                        objDNSSet.Put_
                    Case "notify"
                        objDNSSet.Notify = strValueArray(I)
                        objDNSSet.Put_
                    Case "reverse"
                        objDNSSet.Reverse = strValueArray(I)
                        objDNSSet.Put_
                    Case "securesecondaries"
                        objDNSSet.SecureSecondaries = strValueArray(I)
                        objDNSSet.Put_
                    Case "mastersip"
                        strTempArray(0) = strValueArray(I)
                        objDnsSet.MastersIPAddressesArray = strTempArray
                        objDNSSet.Put_
                    Case "skip"
                        'Do Nothing
                    Case Else
                        blnError = True
                        Call WriteLine(strPropertyArray(I) & " is not valid.")
                End Select
            End If
            
            If blnError = False then
                If strPropertyArray(I) <> "skip" then
                    Call WriteLine(strPropertyArray(I) & " updated.")
                End If
            End If
        End If
    Next

    If blnErrorOccurred("Zone properties not updated.") then
        Exit Sub
    Else
        Call WriteLine("Zone properties are now updated.")
    End If   

End Sub

'********************************************************************
'*
'* Sub DnsDelete()
'*
'* Purpose: Deletes a Zone.
'*
'* Input:   strServer           a machine name
'*          strUserName         the current user's name
'*          strPassword         the current user's password
'*
'* Output:  Results are either printed on screen or saved in strOutputFile.
'*
'********************************************************************

Sub DnsDelete(strServer        , _
              strUserName      , _
              strPassword      , _
              strPropertyArray )


    ON ERROR RESUME NEXT

    Dim objFileSystem, objService, objDNS, objServer
    
    'Establish a connection with the server.
    If blnConnect("root\microsoftdns" , _
                   strUserName , _
                   strPassword , _
                   strServer   , _
                   objService  ) Then
        Call Wscript.Echo("")
        Call Wscript.Echo("Please check the server name, " _
                        & "credentials and WBEM Core.")
        Exit Sub
    End If

    set objServer = objService.Get("MicrosoftDNS_Server.name="".""")
    Set objDNS = objService.Get("MicrosoftDNS_Zone.ContainerName=""" & strPropertyArray(0) & """,DnsServerName=""" & objServer.Name & """,Name=""" & strPropertyArray(0) & """")
    objDns.Delete_
    If blnErrorOccurred("Error Deleting zone.") then Exit Sub
    Call WriteLine("Zone deleted from server " & objserver.name & ".")
   
End Sub           


'********************************************************************
'*
'* Sub DnsADDIP()
'*
'* Purpose: Adds an IP Addresses to an Array.
'*
'* Input:   strServer           a machine name
'*          strUserName         the current user's name
'*          strPassword         the current user's password
'*          strPropertyArray    The properties to change
'*          strValueArray       The New Values
'*
'* Output:  Results are either printed on screen or saved in strOutputFile.
'*
'********************************************************************

Private Sub DnsADDIP(strServer        , _
                     strUserName      , _
                     strPassword      , _
                     strZoneArray     , _
                     strPropertyArray , _
                     strValueArray    )

    'ON ERROR RESUME NEXT
    Dim objFileSystem, objService, objServer, objDnsSet
    Dim strTempArray()
    Dim J, H
    Redim strTempArray(20)
    
    'Establish a connection with the server.
    If blnConnect("root\microsoftdns" , _
                   strUserName , _
                   strPassword , _
                   strServer   , _
                   objService  ) Then
        Call Wscript.Echo("")
        Call Wscript.Echo("Please check the server name, " _
                        & "credentials and WBEM Core.")
        Exit Sub
    End If

    set objServer = objService.Get("MicrosoftDNS_Server.name="".""")

    For I = 0 to ubound(strZoneArray)
        Set objDNSset = objService.Get("MicrosoftDNS_Zone.ContainerName=""" & strZoneArray(0) & """,DnsServerName=""" & objServer.Name & """,Name=""" & strZoneArray(0) & """")

        If blnErrorOccurred(" DNS Server not available.") then Exit Sub
    
        If Not IsEmpty(strZoneArray(I)) then
            Select Case lcase(strPropertyArray(I))
                Case "mastersip"
                    Redim strTempArray(20)
                    If IsNull(objDNSSet.MastersIPAddressesArray) then
                        strTempArray(0) = strValueArray(I)
                        Redim Preserve strTempArray(0)
                        objDNSSet.MastersIPAddressesArray = strTempArray
                    Else
                        J = 0
                        For H = lbound(objDNSSet.MastersIPAddressesArray) to ubound(objDNSSet.MastersIPAddressesArray)
                            strTempArray(H) = objDNSSet.MastersIPAddressesArray(H)
                            J = J + 1
                        Next
                        strTempArray(J) = strValueArray(I)
                        ReDim Preserve strTempArray(J)
                        objDNSSet.MastersIPAddressesArray = strTempArray
                    End If
                    objDNSSet.Put_
                    If err.Number <> 0 then
                        Call WriteLine("Error adding IP address.")
                        Exit Sub                        
                    Else
                        Call WriteLine("IP address successfully added.")
                    End If

                Case "notifyip"
                    Redim strTempArray(20)
                    If IsNull(objDNSSet.NotifyIPAddressesArray) then
                        strTempArray(0) = strValueArray(I)
                        Redim Preserve strTempArray(0)
                        objDNSSet.NotifyIPAddressesArray = strTempArray
                    Else
                        J = 0
                        For H = lbound(objDNSSet.NotifyIPAddressesArray) to ubound(objDNSSet.NotifyIPAddressesArray)
                            strTempArray(H) = objDNSSet.NotifyIPAddressesArray(H)
                            J = J + 1
                        Next
                        strTempArray(J) = strValueArray(I)
                        ReDim Preserve strTempArray(J)
                        objDNSSet.NotifyIPAddressesArray = strTempArray
                    End If
                    objDNSSet.Put_
                    If err.Number <> 0 then
                        Call WriteLine("Error adding IP address.")
                        Exit Sub                        
                    Else
                        Call WriteLine("IP address successfully added.")
                    End If

                Case "secondariesip"
                    Redim strTempArray(20)
                    If IsNull(objDNSSet.SecondariesIPAddressesArray) then
                        strTempArray(0) = strValueArray(I)
                        Redim Preserve strTempArray(0)
                        objDNSSet.SecondariesIPAddressesArray = strTempArray
                    Else
                        J = 0
                        For H = lbound(objDNSSet.SecondariesIPAddressesArray) to ubound(objDNSSet.SecondariesIPAddressesArray)
                            strTempArray(H) = objDNSSet.SecondariesIPAddressesArray(H)
                            J = J + 1
                        Next
                        strTempArray(J) = strValueArray(I)
                        ReDim Preserve strTempArray(J)
                        objDNSSet.SecondariesIPAddressesArray = strTempArray
                    End If
                    objDNSSet.Put_
                    If err.Number <> 0 then
                        Call WriteLine("Error adding IP address.")
                        Exit Sub                        
                    Else
                        Call WriteLine("IP address successfully added.")
                    End If
                
                Case Else
                    Call WriteLine("Cannot add an IP address to " & strPropertyArray(I))

            End Select
        End If    
    Next
End Sub

'********************************************************************
'*
'* Sub DnsDeleteIP()
'*
'* Purpose: Adds an IP Addresses to an Array.
'*
'* Input:   strServer           a machine name
'*          strUserName         the current user's name
'*          strPassword         the current user's password
'*          strPropertyArray    The properties to change
'*          strValueArray       The New Values
'*
'* Output:  Results are either printed on screen or saved in strOutputFile.
'*
'********************************************************************

Private Sub DnsDeleteIP(strServer        , _
                        strUserName      , _
                        strPassword      , _
                        strZoneArray     , _
                        strPropertyArray , _
                        strValueArray     )

    ON ERROR RESUME NEXT
    Dim objFileSystem, objService, objServer, objDnsSet
    Dim J, H
    Dim strTempArray()
    Redim strTempArray(20)
    
    'Establish a connection with the server.
    If blnConnect("root\microsoftdns" , _
                   strUserName , _
                   strPassword , _
                   strServer   , _
                   objService  ) Then
        Call Wscript.Echo("")
        Call Wscript.Echo("Please check the server name, " _
                        & "credentials and WBEM Core.")
        Exit Sub
    End If

    set objServer = objService.Get("MicrosoftDNS_Server.name="".""")
    Set objDNSset = objService.Get("MicrosoftDNS_Zone.ContainerName=""" & strZoneArray(0) & """,DnsServerName=""" & objServer.Name & """,Name=""" & strZoneArray(0) & """")

    For I = 0 to ubound(strPropertyArray)
        If Not IsEmpty(strPropertyArray(I)) then
            Select Case lcase(strPropertyArray(I))
                Case "mastersip"
                    Redim strTempArray(20)
                    If IsNull(objDNSSet.MastersIPAddressesArray) then
                        Call WriteLine("There is no IP addresses to delete.")
                    Else
                        J = 0
                        For H = lbound(objDNSSet.MastersIPAddressesArray) to ubound(objDNSSet.MastersIPAddressesArray)
                            If strValueArray(I) <> objDNSSet.MastersIPAddressesArray(H) then
                                strTempArray(J) = objDNSSet.MastersIPAddressesArray(H)
                                J = J + 1
                            End If
                        Next
                        If J <> 0 then
                            ReDim Preserve strTempArray(J - 1)
                            objDNSSet.MastersIPAddressesArray = strTempArray
                        Else
                            objDnsSet.MastersIPAddressesArray = Null
                        End If
                    End If
                    objDNSSet.Put_
                    If err.Number <> 0 then
                        Call WriteLine("Error deleting IP address.")
                        Exit Sub                        
                    Else
                        Call WriteLine("IP address successfully deleted.")
                    End If

                Case "notifyip"
                    Redim strTempArray(20)
                    If IsNull(objDNSSet.NotifyIPAddressesArray) then
                        Call WriteLine("There is no IP addresses to delete.")
                    Else
                        J = 0
                        For H = lbound(objDNSSet.NotifyIPAddressesArray) to ubound(objDNSSet.NotifyIPAddressesArray)
                            If strValueArray(I) <> objDNSSet.NotifyIPAddressesArray(H) then
                                strTempArray(J) = objDNSSet.NotifyIPAddressesArray(H)
                                J = J + 1
                            End If
                        Next
                        If J <> 0 then
                            ReDim Preserve strTempArray(J - 1)
                            objDNSSet.NotifyIPAddressesArray = strTempArray
                        Else
                            objDnsSet.NotifyIPAddressesArray = Null
                        End If
                    End If
                    objDNSSet.Put_
                    If err.Number <> 0 then
                        Call WriteLine("Error deleting IP address.")
                        Exit Sub                        
                    Else
                        Call WriteLine("IP address successfully deleted.")
                    End If

                Case "secondariesip"
                    Redim strTempArray(20)
                    If IsNull(objDNSSet.SecondariesIPAddressesArray) then
                        Call WriteLine("There is no IP addresses to delete.")
                    Else
                        J = 0
                        For H = lbound(objDNSSet.SecondariesIPAddressesArray) to ubound(objDNSSet.SecondariesIPAddressesArray)
                            If strValueArray(I) <> objDNSSet.SecondariesIPAddressesArray(H) then
                                strTempArray(J) = objDNSSet.SecondariesIPAddressesArray(H)
                                J = J + 1
                            End If
                        Next
                        If J <> 0 then
                            ReDim Preserve strTempArray(J - 1)
                            objDNSSet.SecondariesIPAddressesArray = strTempArray
                        Else
                            objDnsSet.SecondariesIPAddressesArray = Null
                        End If
                    End If
                    objDNSSet.Put_
                    If err.Number <> 0 then
                        Call WriteLine("Error deleting IP address.")
                        Exit Sub                        
                    Else
                        Call WriteLine("IP address successfully deleted.")
                    End If


                Case Else
                    Call WriteLine("Cannot add an IP address to " & strPropertyArray(I))

            End Select
        End If    
    
    Next

End Sub

'********************************************************************
'*
'* Sub DnsPause()
'*
'* Purpose: Pauses a Zone.
'*
'* Input:   strServer           a machine name
'*          strUserName         the current user's name
'*          strPassword         the current user's password
'*
'* Output:  Results are either printed on screen or saved in strOutputFile.
'*
'********************************************************************

Private Sub DnsPause(strServer        , _
                     strUserName      , _
                     strPassword      , _
                     strZoneArray      )


    ON ERROR RESUME NEXT
    Dim objFileSystem, objService, objDnsSet, objServer, Inst
    
    'Establish a connection with the server.
    If blnConnect("root\microsoftdns" , _
                   strUserName , _
                   strPassword , _
                   strServer   , _
                   objService  ) Then
        Call Wscript.Echo("")
        Call Wscript.Echo("Please check the server name, " _
                        & "credentials and WBEM Core.")
        Exit Sub
    End If

    set objServer = objService.Get("MicrosoftDNS_Server.name="".""")
    Set objDNSset = objService.Get("MicrosoftDNS_Zone.ContainerName=""" & strZoneArray(0) & """,DnsServerName=""" & objServer.Name & """,Name=""" & strZoneArray(0) & """")
    If blnErrorOccurred(" DNS Server not available.") then Exit Sub
    If objDnsset.Paused = False then
        Inst = objDNSSet.PauseZone
        If blnErrorOccurred(" Zone not available.") then Exit Sub
        Call WriteLine("Zone " & objDNSSet.Name & " paused on server " & objServer.Name & ".")
    Else
        Call WriteLine("The Zone is already Paused.")
    End If


End Sub

'********************************************************************
'*
'* Sub DnsResume()
'*
'* Purpose: UnPauses a Zone.
'*
'* Input:   strServer           a machine name
'*          strUserName         the current user's name
'*          strPassword         the current user's password
'*
'* Output:  Results are either printed on screen or saved in strOutputFile.
'*
'********************************************************************

Private Sub DnsResume(strServer        , _
                      strUserName      , _
                      strPassword      , _
                      strZoneArray      )


    ON ERROR RESUME NEXT
    Dim objFileSystem, objService, objDnsSet, objServer, Inst
    
    'Establish a connection with the server.
    If blnConnect("root\microsoftdns" , _
                   strUserName , _
                   strPassword , _
                   strServer   , _
                   objService  ) Then
        Call Wscript.Echo("")
        Call Wscript.Echo("Please check the server name, " _
                        & "credentials and WBEM Core.")
        Exit Sub
    End If
    set objServer = objService.Get("MicrosoftDNS_Server.name="".""")
    Set objDNSset = objService.Get("MicrosoftDNS_Zone.ContainerName=""" & strZoneArray(0) & """,DnsServerName=""" & objServer.Name & """,Name=""" & strZoneArray(0) & """")
    If blnErrorOccurred(" DNS Server not available.") then Exit Sub
    If objDNSSet.Paused = True then
        Inst = objDNSSet.ResumeZone
        If blnErrorOccurred(" Zone not available.") then Exit Sub
        Call WriteLine("Zone " & objDNSSet.Name & " resumed on server " & objServer.Name & ".")
    Else
        Call WriteLine("The Zone is not paused.")
    End If


End Sub

'********************************************************************
'*
'* Sub DnsWrite()
'*
'* Purpose: Writes a Zone back to its file.
'*
'* Input:   strServer           a machine name
'*          strUserName         the current user's name
'*          strPassword         the current user's password
'*
'* Output:  Results are either printed on screen or saved in strOutputFile.
'*
'********************************************************************

Private Sub DnsWrite(strServer        , _
                     strUserName      , _
                     strPassword      , _
                     strZoneArray      )


    ON ERROR RESUME NEXT
    Dim objFileSystem, objService, objDnsSet, objServer, Inst
    

    'Establish a connection with the server.
    If blnConnect("root\microsoftdns" , _
                   strUserName , _
                   strPassword , _
                   strServer   , _
                   objService  ) Then
        Call Wscript.Echo("")
        Call Wscript.Echo("Please check the server name, " _
                        & "credentials and WBEM Core.")
        Exit Sub
    End If
    set objServer = objService.Get("MicrosoftDNS_Server.name="".""")
    Set objDNSset = objService.Get("MicrosoftDNS_Zone.ContainerName=""" & strZoneArray(0) & """,DnsServerName=""" & objServer.Name & """,Name=""" & strZoneArray(0) & """")
    If blnErrorOccurred(" DNS Server not available.") then Exit Sub
    Inst = objDNSSet.ResumeZone
    If blnErrorOccurred(" Zone not available.") then Exit Sub
    Call WriteLine("Zone " & objDNSSet.Name & " has written its contents back to the zone file on server " & objServer.Name & ".")
    
End Sub

'********************************************************************
'*
'* Sub DnsUpdate()
'*
'* Purpose: Updates a DS integrated zone with data from the DS.
'*
'* Input:   strServer           a machine name
'*          strUserName         the current user's name
'*          strPassword         the current user's password
'*
'* Output:  Results are either printed on screen or saved in strOutputFile.
'*
'********************************************************************

Private Sub DnsUpdate(strServer        , _
                      strUserName      , _
                      strPassword      , _
                      strZoneArray     )


    ON ERROR RESUME NEXT
    Dim objFileSystem, objService, objDnsSet, objServer, Inst
    
    'Establish a connection with the server.
    If blnConnect("root\microsoftdns" , _
                   strUserName , _
                   strPassword , _
                   strServer   , _
                   objService  ) Then
        Call Wscript.Echo("")
        Call Wscript.Echo("Please check the server name, " _
                        & "credentials and WBEM Core.")
        Exit Sub
    End If
    set objServer = objService.Get("MicrosoftDNS_Server.name="".""")
    Set objDNSset = objService.Get("MicrosoftDNS_Zone.ContainerName=""" & strZoneArray(0) & """,DnsServerName=""" & objServer.Name & """,Name=""" & strZoneArray(0) & """")
    If blnErrorOccurred(" DNS Server not available.") then Exit Sub
    If objDNSSet.ZoneType = 0 then
        Inst = objDNSSet.UpdateDSIntegratedZoneByDataFromDS
        If blnErrorOccurred(" Zone not available.") then Exit Sub
        Call WriteLine("Zone " & objDNSSet.Name & " has been updated from the directory services.")
    Else
        Call WriteLine("Zone " & objDNSSet.Name & " is not a DS Integreated (ZoneType = 0) Zone.")
    End If

End Sub

'********************************************************************
'*
'* Sub DnsReload()
'*
'* Purpose: Reloads a Zone from its ZoneFile.
'*
'* Input:   strServer           a machine name
'*          strUserName         the current user's name
'*          strPassword         the current user's password
'*
'* Output:  Results are either printed on screen or saved in strOutputFile.
'*
'********************************************************************

Private Sub DnsReload(strServer        , _
                      strUserName      , _
                      strPassword      , _
                      strZoneArray      )


    ON ERROR RESUME NEXT
    Dim objFileSystem, objService, objDnsSet, objServer, Inst
    
    'Establish a connection with the server.
    If blnConnect("root\microsoftdns" , _
                   strUserName , _
                   strPassword , _
                   strServer   , _
                   objService  ) Then
        Call Wscript.Echo("")
        Call Wscript.Echo("Please check the server name, " _
                        & "credentials and WBEM Core.")
        Exit Sub
    End If
    set objServer = objService.Get("MicrosoftDNS_Server.name="".""")
    Set objDNSset = objService.Get("MicrosoftDNS_Zone.ContainerName=""" & strZoneArray(0) & """,DnsServerName=""" & objServer.Name & """,Name=""" & strZoneArray(0) & """")
    If blnErrorOccurred(" DNS Server not available.") then Exit Sub
    Inst = objDNSSet.ReloadZoneFromItsDatabase
    If blnErrorOccurred(" Zone not available.") then Exit Sub
    Call WriteLine("Zone " & objDNSSet.Name & " has written its contents back to the zone file on server " & objServer.Name & ".")

End Sub

'********************************************************************
'*
'* Sub DnsRefresh()
'*
'* Purpose: Resfreshes a Secondary Zone from its Master Zone.
'*
'* Input:   strServer           a machine name
'*          strUserName         the current user's name
'*          strPassword         the current user's password
'*
'* Output:  Results are either printed on screen or saved in strOutputFile.
'*
'********************************************************************

Private Sub DnsRefresh(strServer        , _
                      strUserName      , _
                      strPassword      , _
                      strZoneArray      )


    ON ERROR RESUME NEXT
    Dim objFileSystem, objService, objDnsSet, objServer, Inst
    
    'Establish a connection with the server.
    If blnConnect("root\microsoftdns" , _
                   strUserName , _
                   strPassword , _
                   strServer   , _
                   objService  ) Then
        Call Wscript.Echo("")
        Call Wscript.Echo("Please check the server name, " _
                        & "credentials and WBEM Core.")
        Exit Sub
    End If
    set objServer = objService.Get("MicrosoftDNS_Server.name="".""")
    Set objDNSset = objService.Get("MicrosoftDNS_Zone.ContainerName=""" & strZoneArray(0) & """,DnsServerName=""" & objServer.Name & """,Name=""" & strZoneArray(0) & """")
    If blnErrorOccurred(" DNS Server not available.") then Exit Sub
    If objDNSset.ZoneType = 2 then
        Inst = objDNSSet.ForceRefreshOfSecondaryZoneFromMaster
        If blnErrorOccurred("An error occured while refreshing secondary zone.") then Exit Sub
        Call WriteLine("Zone " & objDNSSet.Name & " has written its contents back to the zone file on server " & objServer.Name & ".")
    Else
        Call WriteLine("Zone " & objDNSSet.Name & " is not a secondary (ZoneType = 2) Zone.")
    End If

End Sub

'********************************************************************
'*                                                                  *
'*                           End of Zones                           *
'*                                                                  *
'********************************************************************

'********************************************************************
'*                                                                  *
'*                           Begin of Records                       *
'*                                                                  *
'********************************************************************

Function GetRecord(strServer        , _
					strOwnerName	, _
                    strUserName      , _
                    strPassword      , _
                    strDomain		 , _
                    strRRFilter      , _   
                    strRecordData		)

    'On Error Resume Next
    Dim strTemp
    Dim objFileSystem, objDns, objInst, objDomain, objService
    Dim intReturn
    Dim strQuery
    Dim objQuery

    'Establish a connection with the server.
    If blnConnect("root\microsoftdns" , _
                   strUserName , _
                   strPassword , _
                   strServer   , _
                   objService  ) Then
        Response.Write "<BR>"
        Response.Write "Please check the server name, " _
                        & "credentials and WBEM Core.<BR>"
        Exit Function
    End If

	'Call WriteLine("All Resource Records in " & strDomain & ":", objOutputFile)
	'Set objDNS = objService.ExecQuery("Select * from MicrosoftDNS_ResourceRecord where RelPath=""" & strRRFilter & """")
		'Set Record Class
		strRRFilter = "MicrosoftDNS_" & strRRFilter &"Type"
		strQuery = strStandardQuery(strRRFilter, strContainerName, strServer, strDomain, strOwnerName, strTTL)

        If Not IsEmpty(strRecordData) then
            strQuery = strQuery & " RecordData=""" & strRecordData & """ and"
        End If
        strQuery = Left(strQuery,Len(strQuery)-4)
        'Response.Write "<STRONG>strQuery:</STRONG> " & strQuery & "<BR>"
            
        Set objQuery = objService.ExecQuery(strQuery)  
        
	' Return Records
	Set GetRecord = objQuery
	
End Function

Function GetRecords(strServer        , _
                    strUserName      , _
                    strPassword      , _
                    strDomain		 , _
                    strRRFilter         )

    'On Error Resume Next
    Dim strTemp
    Dim objFileSystem, objDns, objInst, objDomain, objService
    Dim intReturn

    'Establish a connection with the server.
    If blnConnect("root\microsoftdns" , _
                   strUserName , _
                   strPassword , _
                   strServer   , _
                   objService  ) Then
        Call Wscript.Echo("")
        Call Wscript.Echo("Please check the server name, " _
                        & "credentials and WBEM Core.")
        Exit Function
    End If
	
	'Call WriteLine("All Resource Records in " & strDomain & ":", objOutputFile)
	Set objDNS = objService.ExecQuery("Select * from MicrosoftDNS_ResourceRecord where DomainName=""" & strDomain & """",,48)
	
	' Return Records
	Set GetRecords = objDNS
	
End Function


Function strStandardQuery(strClass, strContainerName, strDnsServerName, strDomainName, strOwnerName, strTTL)
	Dim strQuery
    strQuery = "Select * From " & strClass & " Where"
    If Not IsEmpty(strContainerName) then
        strQuery = strQuery & " ContainerName=""" & strContainerName & """ and"
    End If
    If Not IsEmpty(strDnsServerName) then
        strQuery = strQuery & " DnsServerName=""" & strDnsServerName & """ and"
    End If
    If Not IsEmpty(strDomainName) then
        strQuery = strQuery & " DomainName=""" & strDomainName & """ and"
    End If
    If Not IsEmpty(strOwnerName) then
		Select Case lcase(strClass)
			Case lcase("MicrosoftDNS_NSType")
				strQuery = strQuery & " NSHost=""" & strOwnerName & """ and"
				'strQuery = strQuery & " TTL=""10"" and"
			Case Else
				strQuery = strQuery & " OwnerName=""" & strOwnerName & """ and"
		End Select
    End If
    If Not IsEmpty(strTTL) then
        strQuery = strQuery & " TTL=" & strTTL & " and"
    End If
	strStandardQuery = strQuery
End Function

Function strFindType(strText)
	Dim intCounter
	Dim strTemp
	strTemp = ""
	intCounter = 0
	I = 0
	Do Until I > len(strText)
		I = I + 1
		If Mid(strText,I,1) = " " then
			intCounter = intCounter + 1
			If intCounter = 2 then Exit Do
		End If
	Loop
	Do Until I > len(strText)
		I = I + 1
		If Mid(strText,I,1) = " " then
			Exit Do
		Else
			strTemp = strTemp & Mid(strText,I,1)
		End If
	Loop
	strFindType = Trim(strTemp)
End Function
    
'********************************************************************
'*                                                                  *
'*                           End of Records                         *
'*                                                                  *
'********************************************************************

%>