<%
'********************************************************************
'*				---   Web Admin - Exchange 2000 Service   ---
'*
'* Created By: Conrad Agramont & Ed Tremblay
'*
'* Svc-Exchange.asp 
'* 
'* Notes:   	
'*			- Any Items marked optional with [braces] need to have a 
'*				blank string passed into the function.
'*
'*			- Main.asp and Utils.asp libraries need to be called from 
'*				the calling ASP Page for this library.
'*
'********************************************************************

'********************************************************************
'* Offline Folder Server Preference
'*
'*	If this is set to blank, when an Offline Address Book is created, a 
'*		random server wil be picked from all of the available Exchange
'*		servers from within the entire forest.
'*
CONST PREFERED_OAB_EXCH_SERVER		= ""
'*
'********************************************************************

'********************************************************************
'* A Vanity Domain is used to enable Exchange email for for Orgs that 
'*	do not have their own domain.  So all orgs that have a vanity 
'*	domain will all share a domain.  The domain that will be used will
'*  be the default domain (Aka. the AD Domain).  You could created a 
'*  new policy that applies to everyone and make that a higher priority
'*  then the Default Domain.  This way you could have your AD Domain 
'*  still be very different then the domain you want your customers to 
'*  use.
'*
CONST ALLOW_VANITY_DOMAIN			= False ' Do Not Change this setting!!!
CONST VANITY_DOMAIN_IS_DEFAULT		= False
'*
'********************************************************************

'********************************************************************
'* Dim Public Variables

Dim objRecipientPolicyContainer
Dim ResultArrayCounter
Dim SearchArrayItems, ArrayCounter, tempRecipientPolicy, tempGetExchangeServerList

' Set the Size of the Array for use in GetRecipientPolicyContainer()
Dim ResultArrayItems(5)
'*
'********************************************************************

'********************************************************************
' Dim Global Variables used to track Errors that are long running
Dim errSteps
Dim errStepCount
' Initialize Error Holders.
errSteps = ""
errStepCount = 0
'******************************************************************** 

'********************************************************************
'*
'* Function NewOrgProvisionExchange(sOuObj)
'* Purpose: Provision Exchange 2000 Services for an Organization.
'* Input:   	sOuObj			Organization Unit Object (Object)
'*						 
'* Output:  None
'*
'********************************************************************
Function NewOrgProvisionExchange(sOuObj)
On Error Resume Next
	Dim tempOuAdsPath, AllUsersGroupName, AdminsGroupName
	Dim AllUsersAdsPath, AdminsAdsPath

	' Create the Recipient Policy for the Org
	CreateRecipientPolicy sOuObj
		If Err.number <> 0 then
			WriteLog "CreateRecipientPolicy", 1, "Org: " & GetRootOU(sOuObj.AdsPath) & chr(10) & "Failed in Function: NewOrgProvisionExchange()" & chr(10)& "Err.num: " & Err.number & chr(10) & "Err.desc: " & Err.description
			' Need Roll Back Routine
				errSteps = errSteps & ",CreateRecipientPolicy"
				errStepCount = errStepCount + 1
			Exit Function
		End If

	CreateGroupRecipientPolicy sOuObj
		If Err.number <> 0 then
			WriteLog "CreateGroupRecipientPolicy", 1, "Org: " & GetRootOU(sOuObj.AdsPath) & chr(10) & "Failed in Function: NewOrgProvisionExchange()" & chr(10)& "Err.num: " & Err.number & chr(10) & "Err.desc: " & Err.description
			' Need Roll Back Routine
				errSteps = errSteps & ",CreateGroupRecipientPolicy"
				errStepCount = errStepCount + 1
			Exit Function
		End If
	
	'*************************************************
	'*		FEATURE NOT AVAILABLE IN VERSION 1.0.
	'*
	'*	Do not uncomment and use this feature!!!  There is a 
	'*		major bug in the Security settings.  As soon as 
	'*		a fix is available, it will be posted on the 
	'*		Web Admin Website.   URL is available in the 
	'*		Web Admin ReadMe.htm file.
	'*
	'*************************************************
	
	' Create the Global Address List for the Org
	'CreateGAL sOuObj
	'	If Err.number <> 0 then
	'		WriteLog "CreateGAL", 1, "Org: " & GetRootOU(sOuObj.AdsPath) & chr(10) & "Failed in Function: NewOrgProvisionExchange()" & chr(10)& "Err.num: " & Err.number & chr(10) & "Err.desc: " & Err.description
				' Need Roll Back Routine
	'				errSteps = errSteps & ",CreateGAL"
	'				errStepCount = errStepCount + 1
	'		Exit Function
	'	End If
	
	' Get the Info needed to mail enable groups
	tempOuAdsPath			= sOuObj.AdsPath
	AllUsersGroupName		= constALL_USERS_GROUP & GetRootOU(tempOuAdsPath)
	AllUsersAdsPath			= "LDAP://CN=" & AllUsersGroupName & "," & CleanOutProtocol(tempOuAdsPath)
	
	AdminsGroupName			= constADMINS_GROUP & GetRootOU(tempOuAdsPath)
	AdminsAdsPath			= "LDAP://CN=" & AdminsGroupName & "," & CleanOutProtocol(tempOuAdsPath)
	
	' Mail Enable Groups
	MailEnableGroup AllUsersAdsPath, AllUsersGroupName, ParseUsername(AllUsersGroupName)
		If Err.number <> 0 then
			WriteLog "MailEnableGroup", 1, "Org: " & GetRootOU(sOuObj.AdsPath) & chr(10) & "Failed in Function: NewOrgProvisionExchange()" & chr(10)& "Err.num: " & Err.number & chr(10) & "Err.desc: " & Err.description
				' Need Roll Back Routine
					errSteps = errSteps & ",MailEnableGroup (AllUsersGroup)"
					errStepCount = errStepCount + 1
			Exit Function
		End If
	MailEnableGroup AdminsAdsPath, AdminsGroupName, ParseUsername(AdminsGroupName)
		If Err.number <> 0 then
			WriteLog "MailEnableGroup", 1, "Org: " & GetRootOU(sOuObj.AdsPath) & chr(10) & "Failed in Function: NewOrgProvisionExchange()" & chr(10)& "Err.num: " & Err.number & chr(10) & "Err.desc: " & Err.description
				' Need Roll Back Routine
					errSteps = errSteps & ",MailEnableGroup (AdminsGroup)"
					errStepCount = errStepCount + 1
			Exit Function
		End If
	
	' If we get to this point, then all went well.
	WriteLog "NewOrgProvisionExchange", 0, "Org: " & GetRootOU(sOuObj.AdsPath)
	
	' Destroy Objects
	If IsObject(objRecipientPolicyContainer) Then
		Set objRecipientPolicyContainer = Nothing
	End If
	
End Function


'********************************************************************
'*
'* Function CreateRecipientPolicy(sOuObj)
'* Purpose: Create a Recipient Policy for an Organization
'* Input:   	sOuObj			Organization Unit Object (Object)
'*						 
'* Output:  None
'*
'********************************************************************
Function CreateRecipientPolicy(sOuObj)
'On Error Resume Next
	' Dim Object Variables
	Dim rootDSE, RecipientPolicyCont, DefaultPolicy
	Dim NewPolicy
	
	' Dim other Variables
	Dim DFsystemFlags, DFdisabledGatewayProxy, DFmsExchPolicyOptionList, DFGatewayProxy
	Dim DFpurportedSearch, DFmsExchpolicyOrder, DFmsExchProxyGenOptions
	Dim newPurportedSearch, newGatewayProxy, newMsExchpolicyOrder, newMsExchProxyGenOptions
	Dim RootOUName
		
	' Get the Default Policy from the Recipient Policy Container
	Set DefaultPolicy = GetPolicyByName("CN=Default Policy")
	
	' Get Attributes needed from Default Recipient Policy for New Policy
	DFsystemFlags					= DefaultPolicy.systemFlags
	DFdisabledGatewayProxy			= DefaultPolicy.disabledGatewayProxy
	DFmsExchPolicyOptionList		= DefaultPolicy.msExchPolicyOptionList
	DFGatewayProxy					= DefaultPolicy.GatewayProxy
	
	' Kill Un-needed objects
	Set DefaultPolicy = Nothing
	
	'*****************************************************************
	' Begin Creation of the new Recipient Policy
	
	' Get Root OU Name
	RootOUName	= GetRootOU(sOuObj.AdsPath)
	
	' Create the Purported Search Filter 	
	newPurportedSearch = _
		"(&(&(&(|(&(objectCategory=person)(objectSid=*)" &_
		"(!samAccountType:1.2.840.113556.1.4.804:=3))" &_
		"(&(objectCategory=person)(!objectSid=*))" &_
		"(&(objectCategory=group)" &_
		"(groupType:1.2.840.113556.1.4.804:=14))))" &_
		"(objectCategory=user)(mailNickname=*)(userPrincipalName=*@" & RootOUName & ")))"
	
	'Create msExchPurportedSearchUI Array
	Dim tempmsExchPurportedSearcyUIArray, msExchPurportedSearcyUIArray
	tempmsExchPurportedSearcyUIArray = Array("Microsoft.PropertyWell_Condition0=5", "Microsoft.PropertyWell_Property0=userPrincipalName", "Microsoft.PropertyWell_ObjectClass0=user", "Microsoft.PropertyWell_Items=1", "Exchange_ObjectTypes=0", "DsQuery_EnableFilter=0", "DsQuery_ViewMode=4868", "CommonQuery_Form=E23FEE83D957D011B93200A024AB2DBB", "CommonQuery_Handler=5EE6238AC231D011891C00A024AB2DBB")
	msExchPurportedSearcyUIArray = AddToArray(tempmsExchPurportedSearcyUIArray, "Microsoft.PropertyWell_Value0=" & RootOUName)
	
	' Set Static Properties
	newMsExchpolicyOrder			= 1
	newMsExchProxyGenOptions		= 0
		
	newGatewayProxy = AddToArray(DFGatewayProxy,"SMTP:@" & RootOUName)
	
	'****************************
	' Create the New Policy Object
	
	' Get the Recipient Policy Container from AD (In Config Container)
	Set RecipientPolicyCont = GetRecipientPolicyContainer()
	Set NewPolicy = RecipientPolicyCont.Create("msExchRecipientPolicy", "CN=" & RootOUName & " - user")
	
	'****************************
	' Values that are the same as the default policy
	NewPolicy.systemFlags						= DFsystemFlags	
	NewPolicy.msExchPolicyOptionList			= DFmsExchPolicyOptionList
	
	' Same Setting as in Default Policy, but with a new SMTP Setting.
	NewPolicy.gatewayProxy						= newGatewayProxy
	
	'****************************
	'Standard Settings
	NewPolicy.msExchpolicyOrder					= newMsExchpolicyOrder
	NewPolicy.msExchProxyGenOptions				= newMsExchProxyGenOptions
	
	' This setting is used to only apply this policy to a specific set of 
	'	SMTP servers.  It will only modify their Metabase information instead 
	'	of all of them if not set.
	'NewPolicy.msExchAppliesToSmtpVS			= "<SMTP Server List in Array>"
	
	'****************************
	' Unique Settings
	NewPolicy.purportedSearch					= newPurportedSearch
	NewPolicy.msExchPurportedSearchUI			= msExchPurportedSearcyUIArray
	
	NewPolicy.SetInfo
		' Need some error handling
	
	'Kill Objects
	Set RecipientPolicyCont			= Nothing
	Set NewPolicy					= Nothing
	
End Function


'********************************************************************
'*
'* Function CreateRecipientPolicy(sOuObj)
'* Purpose: Create a Recipient Policy for an Organization
'* Input:   	sOuObj			Organization Unit Object (Object)
'*						 
'* Output:  None
'*
'********************************************************************
Function CreateGroupRecipientPolicy(sOuObj)
'On Error Resume Next
	' Dim Object Variables
	Dim rootDSE, RecipientPolicyCont, DefaultPolicy
	Dim NewPolicy
	
	' Dim other Variables
	Dim DFsystemFlags, DFdisabledGatewayProxy, DFmsExchPolicyOptionList, DFGatewayProxy
	Dim DFpurportedSearch, DFmsExchpolicyOrder, DFmsExchProxyGenOptions
	Dim newPurportedSearch, newGatewayProxy, newMsExchpolicyOrder, newMsExchProxyGenOptions
	Dim RootOUName
		
	' Get the Default Policy from the Recipient Policy Container
	Set DefaultPolicy = GetPolicyByName("CN=Default Policy")
	
	' Get Attributes needed from Default Recipient Policy for New Policy
	DFsystemFlags					= DefaultPolicy.systemFlags
	DFdisabledGatewayProxy			= DefaultPolicy.disabledGatewayProxy
	DFmsExchPolicyOptionList		= DefaultPolicy.msExchPolicyOptionList
	DFGatewayProxy					= DefaultPolicy.GatewayProxy
	
	' Kill Un-needed objects
	Set DefaultPolicy = Nothing
	
	'*****************************************************************
	' Begin Creation of the new Recipient Policy
	
	' Get Root OU Name
	RootOUName	= GetRootOU(sOuObj.AdsPath)
	
	' Create the Purported Search Filter 	
	newPurportedSearch = _
		"(&(&(&amp;(&(mailnickname=*) (|" &_ 
		"(&(objectCategory=person)(objectClass=user)(!(homeMDB=*))(!(msExchHomeServerName=*)))" &_
		"(&(objectCategory=person)(objectClass=user)(|(homeMDB=*)(msExchHomeServerName=*)))" &_
		"(&(objectCategory=person)(objectClass=contact))(objectCategory=group)" &_
		"(objectCategory=publicFolder) " &_
		")))(objectCategory=group)(displayName=*@" & RootOUName & ")))"
	
	'Create msExchPurportedSearchUI Array
	Dim tempmsExchPurportedSearcyUIArray, msExchPurportedSearcyUIArray
	tempmsExchPurportedSearcyUIArray = Array("Microsoft.PropertyWell_Condition0=5", "Microsoft.PropertyWell_Property0=displayName", "Microsoft.PropertyWell_ObjectClass0=group", "Microsoft.PropertyWell_Items=1", "Exchange_StgChoice=0", "Exchange_ObjectTypes=31", "DsQuery_EnableFilter=0", "DsQuery_ViewMode=4868", "CommonQuery_Form=F6DA6C00B35DD2118F4000C04F9914BD", "CommonQuery_Handler=5EE6238AC231D011891C00A024AB2DBB")
	msExchPurportedSearcyUIArray = AddToArray(tempmsExchPurportedSearcyUIArray, "Microsoft.PropertyWell_Value0=" & RootOUName)
	
	' Set Static Properties
	newMsExchpolicyOrder			= 1
	newMsExchProxyGenOptions		= 0
		
	newGatewayProxy = AddToArray(DFGatewayProxy,"SMTP:@" & RootOUName)
	
	'****************************
	' Create the New Policy Object
	
	' Get the Recipient Policy Container from AD (In Config Container)
	Set RecipientPolicyCont = GetRecipientPolicyContainer()
	Set NewPolicy = RecipientPolicyCont.Create("msExchRecipientPolicy", "CN=" & RootOUName & " - group")
	
	'****************************
	' Values that are the same as the default policy
	NewPolicy.systemFlags						= DFsystemFlags	
	NewPolicy.msExchPolicyOptionList			= DFmsExchPolicyOptionList
	
	' Same Setting as in Default Policy, but with a new SMTP Setting.
	NewPolicy.gatewayProxy						= newGatewayProxy
	
	'****************************
	'Standard Settings
	NewPolicy.msExchpolicyOrder					= newMsExchpolicyOrder
	NewPolicy.msExchProxyGenOptions				= newMsExchProxyGenOptions
	
	' This setting is used to only apply this policy to a specific set of 
	'	SMTP servers.  It will only modify their Metabase information instead 
	'	of all of them if not set.
	'NewPolicy.msExchAppliesToSmtpVS			= "<SMTP Server List in Array>"
	
	'****************************
	' Unique Settings
	NewPolicy.purportedSearch					= newPurportedSearch
	NewPolicy.msExchPurportedSearchUI			= msExchPurportedSearcyUIArray
	
	NewPolicy.SetInfo
		' Need some error handling
	
	'Kill Objects
	Set RecipientPolicyCont			= Nothing
	Set NewPolicy					= Nothing
	
End Function

'********************************************************************
'*
'* Function AddToArray(arrItem,varNewValue)
'* Purpose: Add and item to an existing Array
'* Input:   	arrItem			Existing Array (Array)
'*				varNewValue		New Item to put in Existing array (String)
'*						 
'* Output:  Array
'*
'********************************************************************
Function AddToArray(arrItem,varNewValue)

	Dim Item, arrItemMax, newArrMax, i, counter
	' Get the Current top limit in the Array
	arrItemMax = Ubound(arrItem)
	newArrMax = arrItemMax + 1
	counter = 0
	
	' Dim the new Array to be one size larger than the current one
	redim NewArray(newArrMax)
		For each i in arrItem
			NewArray(counter) = lcase(i)
			counter = counter + 1
		Next
	'Add Final Value
	NewArray(counter) = varNewValue
	
	'Pass Array Back
	AddToArray = NewArray

End Function

'********************************************************************
'*
'* Function WriteArray(arrItem)
'* Purpose: Dumps and Array to the Screen (Testing Only)
'* Input:   	arrItem			Existing Array (Array)
'*						 
'* Output:  None
'*
'********************************************************************
Function WriteArray(arrItem)
	dim i
		For each i in arrItem
			Response.Write ">> "
			Response.Write i
			Response.Write "<BR>"
		Next
End Function

'********************************************************************
'*
'* Function GetRecipientPolicyContainer()
'* Purpose: Get the Recipient Policy Container
'* Input:   None
'*						 
'* Output:  Object - msExchRecipientPolicyContainer
'*
'*	Notes:  Process of this Function:
'*			1. Check to see if the Recipient Policy Container retrieved ealier
'*				- If So, then just get it from the Global variable and pass it back
'*				- If Not, Keep Going
'*			2. See if the Recipient Policy Container ADSPath is stored in the Application Variable.
'*				- If So, then get the object directly
'*				- If Not, Perform Search
'*			3. When found, first pass the object to the Global Variable
'*			4. Store the Adspath to the Container in an Application Variable
'*			5. Pass the Object back to the source of the calling function
'*
'********************************************************************
Function GetRecipientPolicyContainer()
	
	' Check to see if the Recipient Policy Container was already Retrieved
	If Not isObject(objRecipientPolicyContainer) Then
		If Application("WebAdmin_RecipientPolicyContainer_Adspath") = "" then
			' ***  Begin building The Return List Array


				' Set Counter to 0 for use int AddResultArray Function
				ResultArrayCounter = 0

				' Begin Adding Items to Result Array that you want returned
				AddResultArray "objectClass"
				AddResultArray "objectCategory"
				AddResultArray "Name"
				AddResultArray "distinguishedName"
				AddResultArray "adsPath"
				AddResultArray "cn"

			' *** Done  building The Return List Array


			'Use CheckSearchArray to Set Array Size
			CheckSearchArray "ObjectClass"  ' This is Later Used by the objectClass Attrib
			CheckSearchArray "CN=Default Policy"
	
			' Check to See if there are any items to search for
			If 	ArrayCounter = 0 then
				Response.Write "No Items where entered to search for ..."
				Response.End
			Else
				
				'Reset Counter for use in Array
				ArrayCounter = 0
				
				AddSearchArray "objectClass", "msExchRecipientPolicyContainer"
				
				' Do the Search and set the FindUser Object (ADO RecordSet) as the Results.
				Set tempRecipientPolicy  = SearchGCForObjects(SearchArrayItems,ResultArrayItems,"",0)
				tempRecipientPolicy.MoveFirst
				
				' Pass the Recipient Policy Containter to the Global Variable First.  This way we can reuse later.
				Set objRecipientPolicyContainer = GetAdsObj(Replace(tempRecipientPolicy.fields("adspath"),"GC://","LDAP://"))
				Application("WebAdmin_RecipientPolicyContainer_Adspath") = objRecipientPolicyContainer.AdsPath
				' Kill Objects
				Set tempRecipientPolicy			= Nothing
				
			End If
		Else
			' If the ADSPath to the Container Object already exists in the Application variable, then use that 
			'	path to get the object Directly.
			Set objRecipientPolicyContainer = GetAdsObj(Application("WebAdmin_RecipientPolicyContainer_Adspath"))
		End If
	End If 
		
		' Return the Recipient Policy
		Set GetRecipientPolicyContainer = objRecipientPolicyContainer
	

End Function


'********************************************************************
'*
'* Function MailboxEnableUser(userAdsPath, MailboxPath, UserAlias, userEmailAddress)
'* Purpose: Create a mailbox for a given user
'* Input:   	userAdsPath			AdsPath of the User (String)
'*				MailboxPath			Path of the Mailbox Location (String)
'*				UserAlias			email alias for the user (String)
'*				userEmailAddress	email Address for the User (String)
'*						 
'* Output:  None
'*
'********************************************************************
Function MailboxEnableUser(userAdsPath, MailboxPath, UserAlias, userEmailAddress)
	'Dim Objects
	Dim ObjWebAdmin
	Dim objUser			'As IADsUser
    Dim objPerson		'As New CDO.Person
    Dim objMailStore	'As CDOEXM.IMailboxStore
	
	'Dim Other Variables
	Dim User
	'Dim proxyAddresses(1)
	
	Set objUser = GetObject(userAdsPath)
    ' Clear all email information for the user.
    objUser.PutEx ADS_PROPERTY_CLEAR, "mail", vbNullString
    objUser.PutEx ADS_PROPERTY_CLEAR, "ProxyAddresses", vbNullString
    
    ' The MailNickName must be unique per SMTP domain.
    objUser.Put "mailNickName", UserAlias
    
    ' Save Information
    objUser.SetInfo
    
    ' Destroy user object
    'Set objUser = Nothing
    
    ' Open Path User Object Via CDO
    Set objMailStore = objUser
    
    ' Create the users Mailbox
    objMailStore.CreateMailbox MailboxPath
    
    ' Save the Information.
    'objPerson.DataSource.Save
	'objUser.SetInfo
	
	' Check to see if ASP Mode is enabled.  If so, then do some other steps.
	If ASP_SERVICES_ENABLED Then
		' Get the User object for the given User
		'Set objUser = GetAdsObj(userAdsPath)
	
		' Set the Users msExchQueryBaseDN to the Root OU of their Organization.  This is needed
		'	for Outlook Web Access (OWA).  When a user is using OWA and looks in their Address 
		'	book, OWA does a search into the directory with it's higher level of credentials. 
		'	This enables users to see people in other orgs that normally they would not see based
		'	on the original users credentials and the associated security settings in the Active 
		'	Directory.  So to stop that from happening, OWA looks at the users attribute
		'	msExchQueryBaseDN attribute to filter only the addresses within that OU.
		objUser.msExchQueryBaseDN	= Replace(lcase(GetRootOUAdsPath(userAdsPath)),"ldap://","")

		' Set the msExchPoliciesExcluded Attribute so that we can set the Proxy Addresses
		'	and Email address without waiting for the Recipient Update Service to 
		'	apply the appropirate Recipient Policy.
		'objUser.msExchPoliciesExcluded = "{26491CFC-9E50-4857-861B-0CB8DF22B5D7}"

		' Build the Proxy Address List
		'proxyAddresses(0) = "SMTP:" & userEmailAddress
		'proxyAddresses(1) = "smtp:" & UserAlias & "@" & GetDomain()

		' Set the ProxyForward Address
		'objUser.PutEx ADS_PROPERTY_UPDATE, "proxyAddresses", proxyAddresses

		' Set the Primary email address.
		'objUser.mail = userEmailAddress

		objUser.SetInfo
	End If
	
		If Err.number <> 0 then
			WriteLog "MailboxEnableUser", 1, "User:"  & userAdsPath & chr(10)& "Err.num: " & Err.number & chr(10) & "Err.desc: " & Err.description & chr(10) & chr(10) & "MailStore: " & MailboxPath
		Else
			WriteLog "MailboxEnableUser", 0, "User:"  & userAdsPath & chr(10)& "Err.num: " & Err.number & chr(10) & "Err.desc: " & Err.description & chr(10) & chr(10) & "MailStore: " & MailboxPath			
		End If
	
	' Destroy Objects
	Set ObjWebAdmin = Nothing
	Set objUser = Nothing
	
End Function


'********************************************************************
'*
'* Function MailboxEnableUser(userAdsPath, MailboxPath, UserAlias)
'* Purpose: Create a mailbox for a given user
'* Input:   	userAdsPath		AdsPath of the User (String)
'*				emailAddress	Email Address for the Group (String)
'*				UserAlias		email alias for the user (String)
'*						 
'* Output:  None
'*
'********************************************************************
Function MailEnableGroup(groupAdsPath, emailAddress, groupAlias)
	Dim objGroup			'As IADsGroup
    Dim objPerson			'As New CDO.Person
    Dim objMailRecipient	'As CDOEXM.IMailRecipient
	
	'Dim Other Variables
	Dim User
	
	' Get the User object for the given User
	Set objGroup = GetAdsObj(groupAdsPath)
	
    ' Clear all email information for the user.
    objGroup.PutEx ADS_PROPERTY_CLEAR, "mail", vbNullString
    objGroup.PutEx ADS_PROPERTY_CLEAR, "ProxyAddresses", vbNullString
    
    ' The MailNickName must be unique per SMTP domain.
    objGroup.Put "mailNickName", groupAlias
    
    ' Save Information
    objGroup.SetInfo
    
    ' Pass Group Object to Mail Recipent Object
    Set objMailRecipient = objGroup
    
    ' Mail Enable the group.  Pass in a blank string.  A blank string is used for groups.
    '       If this were for a user or folder, the variable you pass in would be the
    '       forwarding address.  For a group, all members will get the email.
    objMailRecipient.MailEnable ""
	
	' Set the Email Address
	objGroup.Put "mail", emailAddress
	
	' Save Information to AD
	objGroup.SetInfo
		If Err.number <> 0 then
			WriteLog "MailEnableGroup", 1, "Group:"  & groupAdsPath & chr(10)& "Err.num: " & Err.number & chr(10) & "Err.desc: " & Err.description
		Else
			WriteLog "MailEnableGroup", 0, "Group:"  & groupAdsPath & chr(10)& "Err.num: " & Err.number & chr(10) & "Err.desc: " & Err.description			
		End If
	
	' Destroy Objects
	Set objGroup = Nothing
	Set objMailRecipient = Nothing
	
End Function

'********************************************************************
'*
'* Function UpdatePrimaryMailbox(userAdsPath, NewPrimaryAddress)
'* Purpose: Set's the Primary SMTP Mailbox for a given user.
'* Input:   	userAdsPath				AdsPath of User (String)
'*				NewPrimaryAddress		SMTP Alias that will now be the primary.
'*										The SMTP address must already exist in 
'										ProxyAddresses for the given user. (String)
'*						 
'* Output:  None
'*
'********************************************************************
Function UpdatePrimaryMailbox(userAdsPath, NewPrimaryAddress)
    Dim objUser			'As IADsUser
    
    ' Dim Strings
    Dim currentProxyAddresses
    Dim NewProxyAddresses()
    Dim items
    Dim counter					'As Integer
    Dim tempNewAddressValue
    
    ' Get the user object via ADSI
    Set objUser = GetObject(userAdsPath)
    ' Get the Current ProxyAddresses Array
    currentProxyAddresses = objUser.ProxyAddresses
    'For i = LBound(objUser.ProxyAddresses) To UBound(objUser.ProxyAddresses)
    '  Debug.Print objUser.ProxyAddresses(i)
    'Next
    
    'Debug.Print "**** Curent Proxy Addresses"
    For Each items In currentProxyAddresses
        'Debug.Print items
        counter = counter + 1
    Next
    
    ReDim NewProxyAddresses(counter - 1)
    
    ' Reset Counter
    counter = 0
    
    ' Go through the Current Proxy Address list and find the address that matches.
    '   Once there is a match made, make the SMTP: address up
    
    'Debug.Print "**** Building New Proxy Addresses"
    For Each items In currentProxyAddresses
            If LCase(items) = LCase(NewPrimaryAddress) Then
                tempNewAddressValue = Replace(LCase(items), "smtp:", "SMTP:")
                NewProxyAddresses(counter) = tempNewAddressValue
                'Debug.Print "Adding to NewProxyAddresses(" & counter & ") [Default]=" & tempNewAddressValue
            Else
                NewProxyAddresses(counter) = LCase(items)
                'Debug.Print "Adding to NewProxyAddresses(" & counter & ")=" & LCase(items)
            
            End If
        counter = counter + 1
    Next
    
    'Set New Proxy Address in the Directory
    objUser.PutEx ADS_PROPERTY_CLEAR, "ProxyAddresses", vbNullString
    objUser.PutEx ADS_PROPERTY_UPDATE, "ProxyAddresses", NewProxyAddresses
    
    ' Save Information
    objUser.SetInfo
    
    ' Destroy user object
    Set objUser = Nothing
    
End Function

'********************************************************************
'*
'* Function GetExchangeServerList()
'* Purpose: Returns a list of all the Exchange Servers in the Forest
'* Input:   None
'*						 
'* Output:  ADODB Recordset
'*
'********************************************************************
Function GetExchangeServerList()
	
' ***  Begin building The Return List Array


		' Set Counter to 0 for use int AddResultArray Function
		ResultArrayCounter = 0

		' Begin Adding Items to Result Array that you want returned
		AddResultArray "objectClass"
		AddResultArray "objectCategory"
		AddResultArray "Name"
		AddResultArray "distinguishedName"
		AddResultArray "adsPath"
		AddResultArray "cn"

' *** Done  building The Return List Array


	'Use CheckSearchArray to Set Array Size
	CheckSearchArray "ObjectClass"  ' This is Later Used by the objectClass Attrib
	CheckSearchArray "spacer"		' This is just a spacer.
	
	' Check to See if there are any items to search for
	If 	ArrayCounter = 0 then
		Response.Write "No Items where entered to search for ..."
		Response.End
	Else
		
		'Reset Counter for use in Array
		ArrayCounter = 0
		
		AddSearchArray "objectClass", "msExchExchangeServer"
		
		' Do the Search and set the FindUser Object (ADO RecordSet) as the Results.
		Set tempGetExchangeServerList  = SearchGCForObjects(SearchArrayItems,ResultArrayItems,"",0)
		
		' Return the Recordset	
		Set GetExchangeServerList = tempGetExchangeServerList
		
		' Kill Objects
		Set tempGetExchangeServerList			= Nothing
		
	End If
	

End Function

'********************************************************************
'*
'* Function PolicyExist(strPolicyName)
'* Purpose: Checks to see if a Policy exists in the Recipient Policy Container
'* Input:   	strPolicyName		Name of Recipient Policy (String)
'*						 
'* Output:  True/False
'*
'********************************************************************
Function PolicyExist(strPolicyName)
On Error Resume Next
	' Dim Objects
	Dim RecipientPolicyCont, tempPolicy
	
	' Get the Recipient Policy Container from AD (In Config Container)
	Set RecipientPolicyCont = GetRecipientPolicyContainer()
	
	' Check to make sure the Name is correctly Prefixed.
	If Not instr(1,lcase(strPolicyName),"cn=") Then strPolicyName = "CN=" & strPolicyName
	
	' Get the Default Policy from the Recipient Policy Container
	Set tempPolicy = RecipientPolicyCont.GetObject("msExchRecipientPolicy",strPolicyName)
		If Err.number <> 0 then
			PolicyExist = False
			'Response.Write "PolicyExist: False<BR>"
		Else
			PolicyExist = True
			'Response.Write "PolicyExist: True<BR>"
		End If
	
	'Response.Write "strPolicyName: " & strPolicyName & "<BR>"
	'Response.End 
	
	' Kill Objects
	Set tempPolicy					= Nothing
	Set RecipientPolicyCont			= Nothing
End Function

'********************************************************************
'*
'* Function GALExist(strGALName)
'* Purpose: Checks to see if a Global Address List exists.
'* Input:   	strGALName		Name of Global Address List (String)
'*						 
'* Output:  True/False
'*
'********************************************************************
Function GALExist(strGALName)
On Error Resume Next
	' Dim Objects
	Dim AddressListCont, tempPolicy
	
	' Get the Recipient Policy Container from AD (In Config Container)
	Set AddressListCont = GetAddressListContainer()
	' Create the New Address List
	
	' Get the Default Policy from the Recipient Policy Container
	Set tempPolicy = AddressListCont.GetObject("addressBookContainer","CN=" & strGALName)
		If Err.number <> 0 then
			GALExist = False
		Else
			GALExist = True
		End If
	
	' Kill Objects
	Set tempPolicy					= Nothing
	Set AddressListCont				= Nothing
End Function

'********************************************************************
'*
'* Function GetPolicyByName(strPolicyName)
'* Purpose: Get and Return the Recipient Policy
'* Input:   	strPolicyName		Name of Recipient Policy (String)
'*						 
'* Output:  Object - msExchRecipientPolicy
'*
'********************************************************************
Function GetPolicyByName(strPolicyName)
'On Error Resume Next
	' Dim Objects
	Dim RecipientPolicyCont, tempPolicy
	
	Response.Write "strPolicyName: " & strPolicyName
	
	' Get the Recipient Policy Container from AD (In Config Container)
	Set RecipientPolicyCont = GetRecipientPolicyContainer()
	
	' Get the Default Policy from the Recipient Policy Container
	Set tempPolicy = RecipientPolicyCont.GetObject("msExchRecipientPolicy",strPolicyName)
	
	
	' Return the Recipient Policy Object
	Set GetPolicyByName				= tempPolicy
	
	' Kill Objects
	Set tempPolicy					= Nothing
	Set RecipientPolicyCont			= Nothing
	
End Function

'********************************************************************
'*
'* Function GetGALByOUName(strRootName)
'* Purpose: Return a GAL by it's name
'* Input:   strRootName				GAL Name (String)
'*						 
'* Output:  Object - GAL (addressBookContainer)
'*
'********************************************************************
Function GetGALByOUName(strRootName)
	' Dim Objects
	Dim AddressListCont, tempGAL
	
	' Get the Recipient Policy Container from AD (In Config Container)
	Set AddressListCont = GetAddressListContainer()
	Set tempGAL = AddressListCont.GetObject("addressBookContainer","CN=" & strRootName)
	Set GetGALByOUName = tempGAL
	
	' Kill Object(s)
	'Set tempGAL = Nothing
	'Set AddressListCont = Nothing
	
End Function

'********************************************************************
'*
'* Function CreateGAL(sOuObj)
'* Purpose: Creates a GAL for an ASP Exchange Customer.
'* Input:   	sOuObj			Organization Unit Object (Object)
'*						 
'* Output:  None
'*
'********************************************************************
Function CreateGAL(sOuObj)
'On Error Resume Next
	' Dim Object Variables
	'Dim rootDSE, AddressListCont, NewAddressList
	'Dim NewGAL
	'Dim SecurityDescriptor, Dacl, parentSD, parentDACL, copyDACL
	
	' Dim other Variables
	'Dim newPurportedSearch, newGatewayProxy, newMsExchpolicyOrder, newMsExchProxyGenOptions
	'Dim RootOUName, iCurrentControl
	
	
	'*****************************************************************
	' Begin Creation of the new GAL
	
	' Get Root OU Name
	'RootOUName	= GetRootOU(sOuObj.AdsPath)
	
	' Create the Purported Search Filter 
	'newPurportedSearch = _
	'	"(&(&(&(mailnickname=*)"&_
	'	"(|&(objectCategory=person"&_
	'	"(objectClass=user)(username=*@" & RootOUName & "))"&_
	'	"(&(objectCategory=group)(displayName=*@" & RootOUName & "))))))"
	'newPurportedSearch = _
	'	"(&(&(&(|(&(objectCategory=person)(objectSid=*)" &_
	'	"(!samAccountType:1.2.840.113556.1.4.804:=3))" &_
	'	"(&(objectCategory=person)(!objectSid=*))" &_
	'	"(&(objectCategory=group)" &_
	'	"(groupType:1.2.840.113556.1.4.804:=14))))" &_
	'	"(objectCategory=user)(userPrincipalName=*@" & RootOUName & ")))"
	
			
	'Create msExchPurportedSearchUI Array
	'Dim tempmsExchPurportedSearcyUIArray, msExchPurportedSearcyUIArray
	
	'tempmsExchPurportedSearcyUIArray = Array("Microsoft.PropertyWell_Condition0=5", "Microsoft.PropertyWell_Property0=userPrincipalName", "Microsoft.PropertyWell_ObjectClass0=user", "Microsoft.PropertyWell_Items=1", "Exchange_ObjectTypes=0", "DsQuery_EnableFilter=0", "DsQuery_ViewMode=4868", "CommonQuery_Form=E23FEE83D957D011B93200A024AB2DBB", "CommonQuery_Handler=5EE6238AC231D011891C00A024AB2DBB")
	'msExchPurportedSearcyUIArray = AddToArray(tempmsExchPurportedSearcyUIArray, "Microsoft.PropertyWell_Value0=@" & RootOUName)
	
	
	'****************************
	' Create the New Policy Object
	
	' Get the Recipient Policy Container from AD (In Config Container)
	'Set AddressListCont = GetAddressListContainer()
	' Create the New Address List
	'Set NewAddressList = AddressListCont.Create("addressBookContainer", "CN=" & RootOUName)
	'	If Err.number <> 0 then
	'		Response.Write "Error Creating Object<BR>"
	'	Else
	'		Response.Write "Created new AddressBook OK.<BR>"
	'	End If
	
	'
	'****************************
	
	'****************************
	' Unique Settings
	
	'NewAddressList.displayName						= RootOUName
	'NewAddressList.purportedSearch					= newPurportedSearch
	'NewAddressList.msExchPurportedSearchUI			= msExchPurportedSearcyUIArray

	'
	'****************************
	
	'****************************
	'	Save New GAL
	'NewAddressList.SetInfo
	'If Err.number <> 0 then
	'		Response.Write "Error Setting info on Object<BR>"
	'		Response.Write "Err Desc: " & Err.description & "<BR>"
	'		Response.Write "Err numb: " & Err.number  & "<BR>"
	'		Response.Write "Err sour: " & Err.source & "<BR>"
	'		Response.End 
	'	Else
	'		Response.Write "GAL Saved OK.  Now Setting Security<BR>"
	'	End If
	'	
	'****************************
	' Security Settings
	
	' Set Proper Ace Entries
	'Set SecurityDescriptor = NewAddressList.Get("ntSecurityDescriptor")
	'DetailError "Unable to Access the SecurityDescriptor or Access is Denied (sOuObj)"
	'Set Dacl = SecurityDescriptor.DiscretionaryAcl
	'DetailError "Unable to Access the DiscretionaryAcl or Access is Denied (sOuObj)"
	
	' Get the Security Control
	'iCurrentControl = SecurityDescriptor.Control
	
	' Protect this Objects Security Descriptor from Inheritance
	'SecurityDescriptor.Control = iCurrentControl or SE_DACL_PROTECTED
	
	' Get the Parent Containers DACL
	'Set parentSD	= AddressListCont.Get("ntSecurityDescriptor")
	'Set parentDACL	= parentSD.DiscretionaryAcl
	
	' Copy DACL from Parent.
	'Set copyDACL = parentDACL.CopyAccessList()

	' Remove the ability for any user in the Directory to access this
	'	OU or its object
	'DeleteAce copyDACL, "NT AUTHORITY\Authenticated Users"
	
	' Allow Users from within this OU to have read rights to this GAL
	' CHEAT Sheet: AddAce(TrusteeName, gAccessMask, gAceType, gAceFlags, gFlags, gObjectType, gInheritedObjectType)
	'AddAce copyDACL, "AllUsers@" & RootOUName, 131220, 0, 2, 0, 0, 0
	'DetailError "Unable to ADD an ACE (ResetASPSecurity)"
	
	'AddAce copyDACL, "AllUsers@" & RootOUName, 256, 5, 2, 1, "{A1990816-4298-11D1-ADE2-00C04FD8D5CD}", 0
	'DetailError "Unable to ADD an ACE (ResetASPSecurity)"
	
	' Reorder the DACL to a proper State.
	'Set copyDACL = ReorderACL(copyDACL, True)
	
	'*** Add New Dacl to the Security Descriptor
	'SecurityDescriptor.discretionaryAcl = copyDACL
	'SecurityDescriptor.discretionaryAcl = copyDACL
	'NewAddressList.put "ntSecurityDescriptor", SecurityDescriptor
	'
	'****************************
	
	'****************************
	'	Save New GAL
	'NewAddressList.SetInfo
	'If Err.number <> 0 then
	'		Response.Write "Error Setting info on Object<BR>"
	'		Response.Write "Err Desc: " & Err.description & "<BR>"
	'		Response.Write "Err numb: " & Err.number  & "<BR>"
	'		Response.Write "Err sour: " & Err.source & "<BR>"
	'		Response.End 
	'	Else
	'		Response.Write "GAL Securiy Set.  GAL Creation is Complete.<BR>"
	'	End If
		' Need some error handling
	
	'Kill Objects
	'Set NewAddressList				= Nothing
	'Set NewGAL						= Nothing
	'Set parentSD					= Nothing
	'Set parentDACL					= Nothing
	'Set copyDACL					= Nothing
	
End Function

'********************************************************************
'*
'* Function GetAddressListContainer()
'* Purpose: Return the Global Address List Container.
'* Input:   None
'*						 
'* Output:  Object - addressBookContainer
'*
'********************************************************************
Function GetAddressListContainer()
	Dim tempAddressListContainer
	
' ***  Begin building The Return List Array


		' Set Counter to 0 for use int AddResultArray Function
		ResultArrayCounter = 0

		' Begin Adding Items to Result Array that you want returned
		AddResultArray "objectClass"
		AddResultArray "objectCategory"
		AddResultArray "Name"
		AddResultArray "distinguishedName"
		AddResultArray "adsPath"
		AddResultArray "cn"

' *** Done  building The Return List Array


	'Use CheckSearchArray to Set Array Size
	CheckSearchArray "ObjectClass"  ' This is Later Used by the objectClass Attrib
	CheckSearchArray "CN=All Global Address Lists"
	
	' Check to See if there are any items to search for
	If 	ArrayCounter = 0 then
		Response.Write "No Items where entered to search for ..."
		Response.End
	Else
		
		'Reset Counter for use in Array
		ArrayCounter = 0
		
		AddSearchArray "objectClass", "addressBookContainer"
		AddSearchArray "CN", "All Global Address Lists"
		
		' Do the Search and set the FindUser Object (ADO RecordSet) as the Results.
		Set tempAddressListContainer  = SearchGCForObjects(SearchArrayItems,ResultArrayItems,"",0)
		
		tempAddressListContainer.MoveFirst
		
		Set GetAddressListContainer = GetAdsObj(Replace(tempAddressListContainer.fields("adspath"),"GC://","LDAP://"))
		' Kill Objects
		Set tempAddressListContainer			= Nothing
		
	End If
	

End Function


%>