<%
'********************************************************************
'*				---   Web Admin - Web Server Service   ---
'*
'* Created By: Conrad Agramont
'*
'* Svc-WebServer.asp 
'* 
'* Notes:   	
'*			- Any Items marked optional with [braces] need to have a 
'*				blank string passed into the function.
'*
'*			- Main.asp and Utils.asp libraries need to be called from 
'*				the calling ASP Page for this library.
'*
'********************************************************************

'********************************************************************
'* Default Web Content Location
'*
'*	When a new Web Server Service is created for an organization, 
'*		this setting determins where the contents of that web will 
'*		be located on the server selected.
'*
CONST DEFAULT_WEB_CONTENT_LOCATION		= "c:\Inetpub"
'*
'********************************************************************

'********************************************************************
'* Default Web Log Location
'*
'*	When a new Web Server Service is created for an organization, 
'*		this setting determins the name of the Logs folder that will be
'*		created in the Web Site.
'*
CONST DEFAULT_WEB_LOG_LOCATION		= "Logs"
'*
'********************************************************************

'********************************************************************
'* Create Sample Web Site
'*
'*	By Enabling the Sample Web Site, when a new site is created the 
'*		Web Admin will copy all of the contents from the folder
'*		<web admin html folder>\Svc-WebServer\SampleWeb\ and copy it
'*		to the new sites content path.
'*
CONST CREATE_SAMPLE_WEB				= TRUE
'*
'********************************************************************

'********************************************************************
'* New Site Default Information
'*
'*	The following settings are used as default settings for all new sites
'*
CONST IIS_NEW_SITE_DEFAULTDOC		= "index.htm,default.htm,default.asp"
CONST IIS_NEW_SITE_APPISOLATED		= "2"	'0=low, 1=Isolated, 2=Pooled
'*
'********************************************************************

'********************************************************************
'* Public Constants
'*

CONST W3SVC						= "w3svc"
CONST MSFTPSVC					= "MSFTPSVC"
CONST SMTPSVC					= "SMTPSVC"
CONST NNTPSVC					= "NNTPSVC"

CONST IISFTPSERVICENAME			= "IIsFtpService"
CONST IISWEBSERVICENAME			= "IIsWebService"
CONST IISSMTPSERVICENAME		= "IIsSmtpService"
CONST IISNNTPSERVICENAME		= "IIsNntpService"

CONST IISWEBSERVERNAME			= "IIsWebServer"
CONST IISFTPSERVERNAME			= "IIsFtpServer"
CONST IISSMTPSERVERNAME			= "IIsSmtpServer"
CONST IISNNTPSERVERNAME			= "IIsNntpServer"

CONST IISWEBVIRDIRNAME			= "IIsWebVirtualDir"
CONST IISFTPVIRDIRNAME			= "IIsFtpVirtualDir"
CONST IISNNTPVIRDIRNAME			= "IIsNntpVirtualDir"

'*
'********************************************************************

'********************************************************************
'*
'* Function DeleteIISService (iisServer, serviceType,serviceName)
'* Purpose: Delete a Virtual Server on an IIS Machine
'* Input:   iisServer		- Server Name.  Could be a Netbios or DNS 
'*								host name.  (String)
'*
'*			serviceType		- IIS Service Type (Int)
'*								1 = W3SVC
'*								2 = MSFTPSVC
'*								3 = SMTPSVC
'*								4 = NNTPSVC
'*
'*			serviceName		- Service Name or "Instance" (Int)
'*						 
'* Output:  None
'*
'********************************************************************
Function DeleteIISService (iisServer, serviceType,serviceName)
	'Dim Object
	Dim objIisServer
	
	'Dim Other
	Dim iisService, iisServiceServer
	
	Select Case serviceType
		Case 1
			iisService = W3SVC
			iisServiceServer = IISWEBSERVERNAME
		Case 2
			iisService = MSFTPSVC
			iisServiceServer = IISFTPSERVERNAME
		Case 3
			iisService = SMTPSVC
			iisServiceServer = IISSMTPSERVERNAME
		Case 4
			iisService = NNTPSVC
			iisServiceServer = IISNNTPSERVERNAME
	End Select
	
	' Get the Web Server
	Set objIisServer = GetObject("IIS://" & iisServer & "/" & iisService)
	
	' Delete the Object
	objIisServer.Delete "IIsObject", serviceName
End Function

'********************************************************************
'*
'* Function CreateWebServer (webName,webPath, webLogPath, srvIpAddress,srvPort,hostHeader,XML_Config)
'* Purpose: Create a Virtual Web Server on a given Server.
'* Input:   
'*						 
'* Output:  None
'*
'********************************************************************
Function CreateWebServer (webServerName,webName,webPath,webLogPath, srvIpAddress,srvPort,hostHeader,XML_Config)
'On Error Resume Next
'edtrem
On Error Resume Next '/added On Error Resume to handle the 
                     '/ error of not starting the web service if the web site already exists
	'Dim Objects
	Dim webServer, newWebServer
	Dim oFS, xmlDoc
	Dim objNode, objSibNode, oNodes
	
	' Dim Other Variables
	Dim node, i, childNode
	Dim virWebElementName, virWebElementValue
	Dim newWebName, BindingString, NewBindings
	Dim tempShareName
	
	' Create the XML DOM Object
	Set xmlDoc = CreateObject("MSXML.DOMDocument")
	xmlDoc.async = False
	
	' Load XMl Doc
	xmlDoc.loadXML(XML_Config)
	
	' Set the Bindings Information
	BindingString = trim(srvIpAddress) & ":" & trim(srvPort) & ":" & trim(hostHeader)
	
	' Put the Bindings into an array.
	NewBindings = Array(0)
	NewBindings(0) = BindingString
	
	' Get the Web Server
	Set webServer = GetObject("IIS://" & webServerName & "/w3svc")
		If Err.number <> 0 then
			Exit Function
		end If
	
	' Get the New Web Name (It's a number)
	newWebName = GetNextWebNum(webServer)
	
	' Create the new Virtual Web Server
	Set newWebServer = webServer.Create("IIsWebServer", Cstr(newWebName))
	' Quickly save the Web Site
	newWebServer.SetInfo
		If Err.number <> 0 then
			Exit Function
		end If
	
		' Set what port and/or Host Header to listen to and associate to this website
		newWebServer.ServerBindings			= NewBindings
		
		'Fewer than 100k or Medium Sized server
		'newWebServer.ServerSize				= 1
		
		' Get the IIs Web Server Element
		set oNodes = xmlDoc.getElementsByTagName("IIsWebServerElement")
			
			' Go through all of the elements
			For i=0 To oNodes.length -1
				
				set objNode = oNodes.item(i).FirstChild
					If objNode.NodeName = "IIsWebServerElementName" Then
						virWebElementName	= objNode.text
					Else
						virWebElementValue	= objNode.text
					End If
					
				set objSibNode = objNode.nextSibling
					If objSibNode.NodeName = "IIsWebServerElementValue" Then
						virWebElementValue	= objSibNode.text
					Else
						virWebElementName	= objSibNode.text
					End If
				
				' Put information from the XML Doc into
				newWebServer.Put virWebElementName, virWebElementValue
				
			Next
		
		' Name that will be seen in the MMC and on the Web Admin
		newWebServer.ServerComment			= webName
		' Log Path Location
		newWebServer.LogFileDirectory		= webPath & "\" & webLogPath
		' Set Application Proccess Type
		newWebServer.AppIsolated			= IIS_NEW_SITE_APPISOLATED
		' Quickly save the Web Site
		newWebServer.SetInfo
		If Err.number <> 0 then
				' Release the Object
				Set newWebServer = Nothing
				DeleteIISservice webServerName,1,newWebName
			Exit Function
		end If
	
	' Save the Creation of the new Web Server
	newWebServer.SetInfo
		If Err.number <> 0 then
				' Release the Object
				Set newWebServer = Nothing
				DeleteIISservice webServerName,1,newWebName
			Exit Function
		end If
	
	' Create the new Virtual Web Servers Root Directory
	CreateVirDir newWebServer, webServerName, "Root", webPath, xmlDoc
		If Err.number <> 0 then
				' Release the Object
				Set newWebServer = Nothing
				DeleteIISservice webServerName,1,newWebName
			Exit Function
		end If
		
	' If enabled, create the Sample Web Site
	If CREATE_SAMPLE_WEB then
		
		' Get the File System Object and use it to check and verify or create if the path
		'	passed is valid.
		Set oFS = Server.CreateObject("Scripting.FileSystemObject")
			
		' Build the Temp Share Name
		tempShareName = "\\" & webServerName & "\" & GetDriveLetter(webPath) & "$"
		tempShareName = tempShareName & "\" & ClearDriveFromPath(webPath)
		
		' Get the New Web Servers Folder
		oFS.CopyFolder Request.ServerVariables("APPL_PHYSICAL_PATH") & "\Svc-WebServer\SampleWeb", tempShareName
		
	End If
	
	' By Default, Start the Web Service
	newWebServer.Start
		If Err.number <> 0 then
			' Web Server could not start.  This was probably because there was
			'	another web server started with the same bindings information.
			'	Don't stop now.  Keep going.
			Err.Clear 
		End If
	
	'Return the New Web Server IIS Path
	CreateWebServer =  "IIS://" & webServerName & "/w3svc/" & newWebName
End Function

'********************************************************************
'*
'* Function CreateVirDir(objVirWeb)
'* Purpose: Created a Virtual Directory in a given virtual Web Server
'* Input:   objVirWeb	- Virtual Web Server Object (Object)
'*						 
'* Output:  None
'*
'********************************************************************
Function CreateVirDir(objVirWeb, realWebServerName, virWebName, virWebPath, xmlDoc)
On Error Resume Next

	' Dim Objects
	Dim newWebRoot, oFS, tempShareName
	Dim objNode, objSibNode, oNodes
	
	' Dim Other Variables
	Dim node, i, childNode
	Dim virDirElementName, virDirElementValue
	
	' Create the new Virtual Web Servers Root Directory
	Set newWebRoot = objVirWeb.Create("IIsWebVirtualDir", virWebName)
	
	' Get the File System Object and use it to check and verify or create if the path
	'	passed is valid.  If not, the create the Path.
	Set oFS = Server.CreateObject("Scripting.FileSystemObject")
		
	' Build the Temp Share Name
	tempShareName = "\\" & realWebServerName & "\" & GetDriveLetter(virWebPath) & "$"
	tempShareName = tempShareName & "\" & ClearDriveFromPath(virWebPath)
	
	' Check to see if the Folder exists.  If not, Create It.
	If not oFS.FolderExists(tempShareName) then
		Response.Write "tempShareName: " & tempShareName & "<BR>"
		oFS.CreateFolder(tempShareName)
		' Create the Log Folder
		oFS.CreateFolder tempShareName & "\" & DEFAULT_WEB_Log_LOCATION
	else '//edtrem added this
	     Response.Write "The folder for the web site already exists " & tempShareName & "<BR>"
	     Response.Write "this folder will be used for this web site"     	
	End If
		
		'Set the Path
		newWebRoot.Path = virWebPath
		
		' Set the Default Documents
		newWebRoot.DefaultDoc				= IIS_NEW_SITE_DEFAULTDOC
		
		set oNodes = xmlDoc.getElementsByTagName("IIsWebVirtualDirElement")
			
			For i=0 To oNodes.length -1
				
				set objNode = oNodes.item(i).FirstChild
					If objNode.NodeName = "IIsWebVirtualDirName" Then
						virDirElementName	= objNode.text
					Else
						virDirElementValue	= objNode.text
					End If
					
				set objSibNode = objNode.nextSibling
					If objSibNode.NodeName = "IIsWebVirtualDirValue" Then
						virDirElementValue	= objSibNode.text
					Else
						virDirElementName	= objSibNode.text
					End If
				
				' Put information from the XML Doc into
				newWebRoot.Put virDirElementName, virDirElementValue
				
				'Response.Write "virDirElementName:" & virDirElementName & "<BR>"
				'Response.Write "virDirElementValue:" & virDirElementValue & "<BR>"
					If Err.number <> 0 then 
						'Response.Write "Error Num: " & Err.number & "<BR>"
						'Response.Write "Error desc: " & Err.description & "<BR>"
						Exit Function
					End If
				
			Next		
			
		' Quickly save the Web Site
		newWebRoot.SetInfo
		
		' By Default, Set the Web to be an Application of It's Own
		newWebRoot.AppCreate(True)
		newWebRoot.AppFriendlyName = "Default Application"
		
		' By Default, Turn Logging On.
		newWebRoot.DontLog = False
		
		' Save the new Virtual Directory
		newWebRoot.SetInfo
		
End Function


'********************************************************************
'*
'* Function GetNextWebNum(objHost)
'* Purpose: Get the next available web server number.
'* Input:   objHost		- Base w3svc Object of the Server (Object)
'*						 
'* Output:  None
'*
'********************************************************************
Function GetNextWebNum(objHost)
	Dim webSite, CurrentHighNumber
	
	' Set the CurrentHighNumber to zero
	CurrentHighNumber = 0
	
	'Enumerate through all of the WebSite on the Server
	For Each webSite in objHost
		' Ensure that the current object in the w3svc container is indeed
		'	a web server.  If not, the skip to the next service
		If lcase(webSite.Class) = "iiswebserver" then
			' If the current Website number being checked is higher then the 
			'	CurrentHighNumber, then make the current Website number being
			'	checked the new High Number
			If CurrentHighNumber < cint(webSite.Name) Then
				CurrentHighNumber = cint(webSite.Name)
			End If
		End If
	Next
	
	' Now that we have the high number of all the Web Site, return the next number.
	GetNextWebNum = CurrentHighNumber + 1
	
End Function
%>